@@ -1,6 +1,7 @@
 plugins {
   java
   `maven-publish`
+  signing
 }
 
 repositories {
@@ -99,3 +100,8 @@ tasks.test {
   useJUnitPlatform()
   testLogging.showStandardStreams = true
 }
+
+signing {
+  useGpgCmd()
+  sign(publishing.publications["maven"])
+}
