@@ -123,6 +123,9 @@ public class SkinParam implements ISkinParam {
 		if (type == UmlDiagramType.YAML) {
 			UseStyle.setBetaStyle(true);
 		}
+		if (type == UmlDiagramType.HCL) {
+			UseStyle.setBetaStyle(true);
+		}
 		if (type == UmlDiagramType.NWDIAG) {
 			UseStyle.setBetaStyle(true);
 		}
@@ -610,7 +613,11 @@ public class SkinParam implements ISkinParam {
 	}
 
 	public int getDpi() {
-		return getAsInt("dpi", 96);
+		final int defaultValue = 96;
+		final int dpi = getAsInt("dpi", defaultValue);
+		if (dpi <= 0)
+			return defaultValue;
+		return dpi;
 	}
 
 	public DotSplines getDotSplines() {
