@@ -2,7 +2,7 @@
  * PlantUML : a free UML diagram generator
  * ========================================================================
  *
- * (C) Copyright 2009-2017, Arnaud Roques
+ * (C) Copyright 2009-2020, Arnaud Roques
  *
  * Project Info:  http://plantuml.com
  * 
@@ -47,15 +47,15 @@ import java.util.Locale;
 import java.util.Map;
 import java.util.TimeZone;
 
+import ext.plantuml.com.ctreber.acearth.ACearth;
+import ext.plantuml.com.ctreber.acearth.ConfigurationACearth;
+import ext.plantuml.com.ctreber.acearth.plugins.markers.Marker;
 import net.sourceforge.plantuml.AbstractPSystem;
 import net.sourceforge.plantuml.FileFormatOption;
 import net.sourceforge.plantuml.api.ImageDataSimple;
 import net.sourceforge.plantuml.core.DiagramDescription;
 import net.sourceforge.plantuml.core.ImageData;
-
-import ext.plantuml.com.ctreber.acearth.ACearth;
-import ext.plantuml.com.ctreber.acearth.ConfigurationACearth;
-import ext.plantuml.com.ctreber.acearth.plugins.markers.Marker;
+import net.sourceforge.plantuml.core.UmlSource;
 
 public class PSystemXearth extends AbstractPSystem {
 
@@ -71,7 +71,8 @@ public class PSystemXearth extends AbstractPSystem {
 			"terminatorDiscontinuity", "gridDivision", "gridPixelDivision", "bigStars");
 	final private Collection<String> booleans = Arrays.asList("shadeP", "gridP", "starsP");
 
-	public PSystemXearth(int width, int height, Map<String, String> config, List<Marker> markers) {
+	public PSystemXearth(UmlSource source, int width, int height, Map<String, String> config, List<Marker> markers) {
+		super(source);
 		this.width = width;
 		this.height = height;
 		this.config = config;
@@ -79,33 +80,35 @@ public class PSystemXearth extends AbstractPSystem {
 	}
 
 	@Override
-	final protected ImageData exportDiagramNow(OutputStream os, int num, FileFormatOption fileFormat, long seed)
+	final protected ImageData exportDiagramNow(OutputStream os, int num, FileFormatOption fileFormat)
 			throws IOException {
-		final ACearth earth = new ACearth(markers);
-		final ConfigurationACearth conf = earth.getConf();
-		conf.setInt("imageWidth", width);
-		conf.setInt("imageHeight", height);
+		synchronized (PSystemXearth.class) {
+			final ACearth earth = new ACearth(markers);
+			final ConfigurationACearth conf = earth.getConf();
+			conf.setInt("imageWidth", width);
+			conf.setInt("imageHeight", height);
 
-		for (Map.Entry<String, String> ent : config.entrySet()) {
-			final String key = ent.getKey();
-			final String value = ent.getValue();
-			if (key.equalsIgnoreCase("GMT")) {
-				final Date date = extractGmt(value);
-				conf.setInt("fixedTime", (int) (date.getTime() / 1000L));
-			} else if (enums.contains(key)) {
-				conf.getMOEnum(key).set(value);
-			} else if (doubles.contains(key)) {
-				conf.setDouble(key, Double.parseDouble(value));
-			} else if (integers.contains(key)) {
-				conf.setInt(key, Integer.parseInt(value));
-			} else if (booleans.contains(key)) {
-				conf.setBoolean(key, value.equalsIgnoreCase("true"));
-			} else {
-				throw new UnsupportedOperationException(key);
+			for (Map.Entry<String, String> ent : config.entrySet()) {
+				final String key = ent.getKey();
+				final String value = ent.getValue();
+				if (key.equalsIgnoreCase("GMT")) {
+					final Date date = extractGmt(value);
+					conf.setInt("fixedTime", (int) (date.getTime() / 1000L));
+				} else if (enums.contains(key)) {
+					conf.getMOEnum(key).set(value);
+				} else if (doubles.contains(key)) {
+					conf.setDouble(key, Double.parseDouble(value));
+				} else if (integers.contains(key)) {
+					conf.setInt(key, Integer.parseInt(value));
+				} else if (booleans.contains(key)) {
+					conf.setBoolean(key, value.equalsIgnoreCase("true"));
+				} else {
+					throw new UnsupportedOperationException(key);
+				}
 			}
+			earth.exportPng(os);
+			return new ImageDataSimple(width, height);
 		}
-		earth.exportPng(os);
-		return new ImageDataSimple(width, height);
 	}
 
 	private Date extractGmt(String s) {
