@@ -35,12 +35,15 @@
  */
 package net.sourceforge.plantuml.activitydiagram3;
 
+import net.sourceforge.plantuml.ISkinParam;
 import net.sourceforge.plantuml.activitydiagram3.ftile.Ftile;
 import net.sourceforge.plantuml.activitydiagram3.ftile.FtileFactory;
 import net.sourceforge.plantuml.activitydiagram3.ftile.Swimable;
 import net.sourceforge.plantuml.activitydiagram3.ftile.Swimlane;
+import net.sourceforge.plantuml.activitydiagram3.gtile.Gtile;
 import net.sourceforge.plantuml.command.CommandExecutionResult;
 import net.sourceforge.plantuml.cucadiagram.Display;
+import net.sourceforge.plantuml.graphic.StringBounder;
 import net.sourceforge.plantuml.graphic.color.Colors;
 import net.sourceforge.plantuml.sequencediagram.NotePosition;
 import net.sourceforge.plantuml.sequencediagram.NoteType;
@@ -49,6 +52,8 @@ public interface Instruction extends Swimable {
 
 	public Ftile createFtile(FtileFactory factory);
 
+	public Gtile createGtile(ISkinParam skinParam, StringBounder stringBounder);
+
 	public CommandExecutionResult add(Instruction other);
 
 	public boolean kill();
@@ -56,7 +61,7 @@ public interface Instruction extends Swimable {
 	public LinkRendering getInLinkRendering();
 
 	public boolean addNote(Display note, NotePosition position, NoteType type, Colors colors, Swimlane swimlaneNote);
-	
+
 	public boolean containsBreak();
 
 }
