@@ -37,11 +37,15 @@ package net.sourceforge.plantuml.activitydiagram3;
 
 import java.util.Objects;
 
+import net.sourceforge.plantuml.ISkinParam;
 import net.sourceforge.plantuml.activitydiagram3.ftile.Ftile;
 import net.sourceforge.plantuml.activitydiagram3.ftile.FtileBreak;
 import net.sourceforge.plantuml.activitydiagram3.ftile.FtileFactory;
 import net.sourceforge.plantuml.activitydiagram3.ftile.Swimlane;
+import net.sourceforge.plantuml.activitydiagram3.gtile.Gtile;
+import net.sourceforge.plantuml.activitydiagram3.gtile.GtileBreak;
 import net.sourceforge.plantuml.command.CommandExecutionResult;
+import net.sourceforge.plantuml.graphic.StringBounder;
 
 public class InstructionBreak extends MonoSwimable implements Instruction {
 
@@ -52,14 +56,22 @@ public class InstructionBreak extends MonoSwimable implements Instruction {
 		this.inlinkRendering = Objects.requireNonNull(inlinkRendering);
 	}
 
+	@Override
 	public Ftile createFtile(FtileFactory factory) {
 		return new FtileBreak(factory.skinParam(), getSwimlaneIn());
 	}
 
+	@Override
+	public Gtile createGtile(ISkinParam skinParam, StringBounder stringBounder) {
+		return new GtileBreak(stringBounder, skinParam, getSwimlaneIn());
+	}
+
+	@Override
 	public CommandExecutionResult add(Instruction other) {
 		throw new UnsupportedOperationException();
 	}
 
+	@Override
 	final public boolean kill() {
 		return false;
 	}
