@@ -2,7 +2,7 @@
  * PlantUML : a free UML diagram generator
  * ========================================================================
  *
- * (C) Copyright 2009-2017, Arnaud Roques
+ * (C) Copyright 2009-2020, Arnaud Roques
  *
  * Project Info:  http://plantuml.com
  * 
@@ -41,22 +41,38 @@ import java.util.HashSet;
 import java.util.List;
 import java.util.Set;
 
+import net.sourceforge.plantuml.ISkinParam;
 import net.sourceforge.plantuml.activitydiagram3.ftile.Ftile;
 import net.sourceforge.plantuml.activitydiagram3.ftile.FtileDecorateWelding;
 import net.sourceforge.plantuml.activitydiagram3.ftile.FtileEmpty;
 import net.sourceforge.plantuml.activitydiagram3.ftile.FtileFactory;
 import net.sourceforge.plantuml.activitydiagram3.ftile.Swimlane;
 import net.sourceforge.plantuml.activitydiagram3.ftile.WeldingPoint;
+import net.sourceforge.plantuml.activitydiagram3.gtile.Gtile;
+import net.sourceforge.plantuml.activitydiagram3.gtile.GtileAssembly;
+import net.sourceforge.plantuml.activitydiagram3.gtile.GtileEmpty;
+import net.sourceforge.plantuml.command.CommandExecutionResult;
 import net.sourceforge.plantuml.cucadiagram.Display;
+import net.sourceforge.plantuml.graphic.StringBounder;
 import net.sourceforge.plantuml.graphic.color.Colors;
 import net.sourceforge.plantuml.sequencediagram.NotePosition;
 import net.sourceforge.plantuml.sequencediagram.NoteType;
 
 public class InstructionList extends WithNote implements Instruction, InstructionCollection {
 
-	private final List<Instruction> all = new ArrayList<Instruction>();
+	private final List<Instruction> all = new ArrayList<>();
 	private final Swimlane defaultSwimlane;
 
+	@Override
+	public boolean containsBreak() {
+		for (Instruction ins : all) {
+			if (ins.containsBreak()) {
+				return true;
+			}
+		}
+		return false;
+	}
+
 	public InstructionList() {
 		this(null);
 	}
@@ -65,24 +81,50 @@ public class InstructionList extends WithNote implements Instruction, Instructio
 		return all.isEmpty();
 	}
 
-	public boolean isOnlySingleStop() {
-		return all.size() == 1 && getLast() instanceof InstructionStop
-				&& ((InstructionStop) getLast()).hasNotes() == false;
+	public boolean isOnlySingleStopOrSpot() {
+		if (all.size() != 1) {
+			return false;
+		}
+		if (getLast() instanceof InstructionSpot) {
+			return true;
+		}
+		return getLast() instanceof InstructionStop && ((InstructionStop) getLast()).hasNotes() == false;
 	}
 
 	public InstructionList(Swimlane defaultSwimlane) {
 		this.defaultSwimlane = defaultSwimlane;
 	}
 
-	public void add(Instruction ins) {
+	@Override
+	public CommandExecutionResult add(Instruction ins) {
 		all.add(ins);
+		return CommandExecutionResult.ok();
 	}
 
+	@Override
+	public Gtile createGtile(ISkinParam skinParam, StringBounder stringBounder) {
+		if (all.size() == 0) {
+			return new GtileEmpty(stringBounder, skinParam, defaultSwimlane);
+		}
+		Gtile result = null;
+		for (Instruction ins : all) {
+			final Gtile cur = ins.createGtile(skinParam, stringBounder);
+
+			if (result == null) {
+				result = cur;
+			} else {
+				result = new GtileAssembly(result, cur, ins.getInLinkRendering());
+			}
+		}
+		return result;
+	}
+
+	@Override
 	public Ftile createFtile(FtileFactory factory) {
 		if (all.size() == 0) {
 			return new FtileEmpty(factory.skinParam(), defaultSwimlane);
 		}
-		final List<WeldingPoint> breaks = new ArrayList<WeldingPoint>();
+		final List<WeldingPoint> breaks = new ArrayList<>();
 		Ftile result = eventuallyAddNote(factory, null, getSwimlaneIn());
 		for (Instruction ins : all) {
 			Ftile cur = ins.createFtile(factory);
@@ -110,6 +152,7 @@ public class InstructionList extends WithNote implements Instruction, Instructio
 		return result;
 	}
 
+	@Override
 	final public boolean kill() {
 		if (all.size() == 0) {
 			return false;
@@ -117,10 +160,12 @@ public class InstructionList extends WithNote implements Instruction, Instructio
 		return getLast().kill();
 	}
 
+	@Override
 	public LinkRendering getInLinkRendering() {
 		return all.iterator().next().getInLinkRendering();
 	}
 
+	@Override
 	public Instruction getLast() {
 		if (all.size() == 0) {
 			return null;
@@ -128,6 +173,7 @@ public class InstructionList extends WithNote implements Instruction, Instructio
 		return all.get(all.size() - 1);
 	}
 
+	@Override
 	public boolean addNote(Display note, NotePosition position, NoteType type, Colors colors, Swimlane swimlaneNote) {
 		if (getLast() == null) {
 			return super.addNote(note, position, type, colors, swimlaneNote);
@@ -135,23 +181,17 @@ public class InstructionList extends WithNote implements Instruction, Instructio
 		return getLast().addNote(note, position, type, colors, swimlaneNote);
 	}
 
+	@Override
 	public Set<Swimlane> getSwimlanes() {
 		return getSwimlanes2(all);
 	}
 
+	@Override
 	public Swimlane getSwimlaneIn() {
 		return defaultSwimlane;
-		// final Set<Swimlane> swimlanes = getSwimlanes();
-		// if (swimlanes.size() == 0) {
-		// return null;
-		// }
-		// if (swimlanes.size() == 1) {
-		// return swimlanes.iterator().next();
-		// }
-		// System.err.println("foo1="+getClass());
-		// return all.get(0).getSwimlaneIn();
 	}
 
+	@Override
 	public Swimlane getSwimlaneOut() {
 		final Set<Swimlane> swimlanes = getSwimlanes();
 		if (swimlanes.size() == 0) {
@@ -164,7 +204,7 @@ public class InstructionList extends WithNote implements Instruction, Instructio
 	}
 
 	public static Set<Swimlane> getSwimlanes2(List<? extends Instruction> list) {
-		final Set<Swimlane> result = new HashSet<Swimlane>();
+		final Set<Swimlane> result = new HashSet<>();
 		for (Instruction ins : list) {
 			result.addAll(ins.getSwimlanes());
 		}
