@@ -2,7 +2,7 @@
  * PlantUML : a free UML diagram generator
  * ========================================================================
  *
- * (C) Copyright 2009-2017, Arnaud Roques
+ * (C) Copyright 2009-2020, Arnaud Roques
  *
  * Project Info:  http://plantuml.com
  * 
@@ -49,6 +49,7 @@ import net.sourceforge.plantuml.graphic.StringBounder;
 import net.sourceforge.plantuml.ugraphic.MinMax;
 import net.sourceforge.plantuml.ugraphic.UStroke;
 import net.sourceforge.plantuml.ugraphic.UTranslate;
+import net.sourceforge.plantuml.ugraphic.color.HColorSet;
 
 public abstract class AbstractFtile extends AbstractTextBlock implements Ftile {
 
@@ -65,6 +66,10 @@ public abstract class AbstractFtile extends AbstractTextBlock implements Ftile {
 		return skinParam;
 	}
 
+	final public HColorSet getIHtmlColorSet() {
+		return skinParam.getIHtmlColorSet();
+	}
+
 	public LinkRendering getInLinkRendering() {
 		return LinkRendering.none();
 	}
@@ -98,7 +103,7 @@ public abstract class AbstractFtile extends AbstractTextBlock implements Ftile {
 	}
 
 	public HorizontalAlignment arrowHorizontalAlignment() {
-		return skinParam.getHorizontalAlignment(AlignmentParam.arrowMessageAlignment, null);
+		return skinParam.getHorizontalAlignment(AlignmentParam.arrowMessageAlignment, null, false, null);
 	}
 
 	private FtileGeometry cachedGeometry;
