@@ -2,7 +2,7 @@
  * PlantUML : a free UML diagram generator
  * ========================================================================
  *
- * (C) Copyright 2009-2017, Arnaud Roques
+ * (C) Copyright 2009-2020, Arnaud Roques
  *
  * Project Info:  http://plantuml.com
  * 
@@ -42,49 +42,59 @@ import java.util.Collections;
 import java.util.HashSet;
 import java.util.Set;
 
+import net.sourceforge.plantuml.AlignmentParam;
 import net.sourceforge.plantuml.ColorParam;
 import net.sourceforge.plantuml.Dimension2DDouble;
 import net.sourceforge.plantuml.Direction;
 import net.sourceforge.plantuml.FontParam;
 import net.sourceforge.plantuml.ISkinParam;
 import net.sourceforge.plantuml.LineBreakStrategy;
+import net.sourceforge.plantuml.UseStyle;
 import net.sourceforge.plantuml.activitydiagram3.PositionedNote;
 import net.sourceforge.plantuml.activitydiagram3.ftile.AbstractFtile;
 import net.sourceforge.plantuml.activitydiagram3.ftile.Ftile;
 import net.sourceforge.plantuml.activitydiagram3.ftile.FtileGeometry;
 import net.sourceforge.plantuml.activitydiagram3.ftile.Swimlane;
 import net.sourceforge.plantuml.creole.CreoleMode;
-import net.sourceforge.plantuml.creole.CreoleParser;
+import net.sourceforge.plantuml.creole.Parser;
 import net.sourceforge.plantuml.creole.Sheet;
 import net.sourceforge.plantuml.creole.SheetBlock1;
 import net.sourceforge.plantuml.creole.SheetBlock2;
 import net.sourceforge.plantuml.creole.Stencil;
 import net.sourceforge.plantuml.graphic.FontConfiguration;
 import net.sourceforge.plantuml.graphic.HorizontalAlignment;
-import net.sourceforge.plantuml.graphic.HtmlColor;
 import net.sourceforge.plantuml.graphic.StringBounder;
 import net.sourceforge.plantuml.graphic.TextBlock;
 import net.sourceforge.plantuml.sequencediagram.NotePosition;
 import net.sourceforge.plantuml.sequencediagram.NoteType;
 import net.sourceforge.plantuml.skin.rose.Rose;
+import net.sourceforge.plantuml.style.PName;
+import net.sourceforge.plantuml.style.SName;
+import net.sourceforge.plantuml.style.Style;
+import net.sourceforge.plantuml.style.StyleSignature;
+import net.sourceforge.plantuml.style.Styleable;
 import net.sourceforge.plantuml.svek.image.Opale;
 import net.sourceforge.plantuml.ugraphic.UGraphic;
 import net.sourceforge.plantuml.ugraphic.UStroke;
 import net.sourceforge.plantuml.ugraphic.UTranslate;
+import net.sourceforge.plantuml.ugraphic.color.HColor;
 
-public class FtileWithNoteOpale extends AbstractFtile implements Stencil {
+public class FtileWithNoteOpale extends AbstractFtile implements Stencil, Styleable {
 
 	private final Ftile tile;
 	private final Opale opale;
 
-	// private final HtmlColor arrowColor;
 	private final NotePosition notePosition;
 	private final double suppSpace = 20;
 	private final Swimlane swimlaneNote;
 
+	public StyleSignature getDefaultStyleDefinition() {
+		return StyleSignature.of(SName.root, SName.element, SName.activityDiagram, SName.note);
+	}
+
 	public Set<Swimlane> getSwimlanes() {
 		if (swimlaneNote != null) {
-			final Set<Swimlane> result = new HashSet<Swimlane>(tile.getSwimlanes());
+			final Set<Swimlane> result = new HashSet<>(tile.getSwimlanes());
 			result.add(swimlaneNote);
 			return Collections.unmodifiableSet(result);
 		}
@@ -128,16 +138,35 @@ public class FtileWithNoteOpale extends AbstractFtile implements Stencil {
 
 		final Rose rose = new Rose();
 
-		final HtmlColor noteBackgroundColor = rose.getHtmlColor(skinParam, ColorParam.noteBackground);
-		final HtmlColor borderColor = rose.getHtmlColor(skinParam, ColorParam.noteBorder);
+		final HColor noteBackgroundColor;
+		final HColor borderColor;
+		final FontConfiguration fc;
 
-		final FontConfiguration fc = new FontConfiguration(skinParam, FontParam.NOTE, null);
+		final double shadowing;
+		final LineBreakStrategy wrapWidth;
+		if (UseStyle.useBetaStyle()) {
+			final Style style = getDefaultStyleDefinition().getMergedStyle(skinParam.getCurrentStyleBuilder())
+					.eventuallyOverride(note.getColors());
+			noteBackgroundColor = style.value(PName.BackGroundColor).asColor(skinParam.getThemeStyle(),
+					getIHtmlColorSet());
+			borderColor = style.value(PName.LineColor).asColor(skinParam.getThemeStyle(), getIHtmlColorSet());
+			fc = style.getFontConfiguration(skinParam.getThemeStyle(), getIHtmlColorSet());
+			shadowing = style.value(PName.Shadowing).asDouble();
+			wrapWidth = style.wrapWidth();
+		} else {
+			noteBackgroundColor = rose.getHtmlColor(skinParam, ColorParam.noteBackground);
+			borderColor = rose.getHtmlColor(skinParam, ColorParam.noteBorder);
+			fc = new FontConfiguration(skinParam, FontParam.NOTE, null);
+			shadowing = skinParam.shadowing(null) ? 4 : 0;
+			wrapWidth = skinParam.wrapWidth();
+		}
 
-		final Sheet sheet = new CreoleParser(fc, skinParam.getDefaultTextAlignment(HorizontalAlignment.LEFT),
-				skinParam, CreoleMode.FULL).createSheet(note.getDisplay());
-		final TextBlock text = new SheetBlock2(new SheetBlock1(sheet, LineBreakStrategy.NONE, skinParam.getPadding()),
-				this, new UStroke(1));
-		opale = new Opale(borderColor, noteBackgroundColor, text, skinParam.shadowing(), withLink);
+		final HorizontalAlignment align = skinParam.getHorizontalAlignment(AlignmentParam.noteTextAlignment, null,
+				false, null);
+		final Sheet sheet = Parser.build(fc, align, skinParam, CreoleMode.FULL).createSheet(note.getDisplay());
+		final TextBlock text = new SheetBlock2(new SheetBlock1(sheet, wrapWidth, skinParam.getPadding()), this,
+				new UStroke(1));
+		opale = new Opale(shadowing, borderColor, noteBackgroundColor, text, withLink);
 
 	}
 
@@ -154,6 +183,13 @@ public class FtileWithNoteOpale extends AbstractFtile implements Stencil {
 		}
 
 		return new UTranslate(marge, yForFtile);
+	}
+
+	@Override
+	public UTranslate getTranslateFor(Ftile child, StringBounder stringBounder) {
+		if (child == tile)
+			return new UTranslate();
+		return super.getTranslateFor(child, stringBounder);
 
 	}
 
@@ -165,7 +201,7 @@ public class FtileWithNoteOpale extends AbstractFtile implements Stencil {
 		final double yForNote = (dimTotal.getHeight() - dimNote.getHeight()) / 2;
 
 		if (notePosition == NotePosition.LEFT) {
-			return new UTranslate(0, yForNote);
+			return UTranslate.dy(yForNote);
 		}
 		final double dx = dimTotal.getWidth() - dimNote.getWidth();
 		return new UTranslate(dx, yForNote);
@@ -193,13 +229,14 @@ public class FtileWithNoteOpale extends AbstractFtile implements Stencil {
 			final Point2D pp2 = new Point2D.Double(-suppSpace, dimNote.getHeight() / 2);
 			opale.setOpale(strategy, pp1, pp2);
 		}
-		if (swimlaneNote == null || intoSw == swimlaneNote) {
+		if (ug instanceof UGraphicInterceptorOneSwimlane == false || swimlaneNote == null || intoSw == swimlaneNote) {
 			opale.drawU(ug.apply(getTranslateForOpale(ug)));
 		}
 		ug.apply(getTranslate(stringBounder)).draw(tile);
 	}
 
-	public FtileGeometry calculateDimension(StringBounder stringBounder) {
+	@Override
+	protected FtileGeometry calculateDimensionFtile(StringBounder stringBounder) {
 		final Dimension2D dimTotal = calculateDimensionInternal(stringBounder);
 		final FtileGeometry orig = tile.calculateDimension(stringBounder);
 		final UTranslate translate = getTranslate(stringBounder);
