@@ -46,7 +46,7 @@ import net.sourceforge.plantuml.activitydiagram3.ftile.AbstractConnection;
 import net.sourceforge.plantuml.activitydiagram3.ftile.Arrows;
 import net.sourceforge.plantuml.activitydiagram3.ftile.Connection;
 import net.sourceforge.plantuml.activitydiagram3.ftile.ConnectionTranslatable;
-import net.sourceforge.plantuml.activitydiagram3.ftile.Diamond;
+import net.sourceforge.plantuml.activitydiagram3.ftile.Hexagon;
 import net.sourceforge.plantuml.activitydiagram3.ftile.Ftile;
 import net.sourceforge.plantuml.activitydiagram3.ftile.FtileGeometry;
 import net.sourceforge.plantuml.activitydiagram3.ftile.FtileUtils;
@@ -145,7 +145,7 @@ public class FtileIfWithLinks extends FtileIfWithDiamonds {
 			p2 = translate2.getTranslated(p2);
 			final Direction newDirection = Direction.leftOrRight(p1, p2);
 			if (originalDirection != newDirection) {
-				final double delta = (originalDirection == Direction.RIGHT ? -1 : 1) * Diamond.diamondHalfSize;
+				final double delta = (originalDirection == Direction.RIGHT ? -1 : 1) * Hexagon.hexagonHalfSize;
 				final Dimension2D dimDiamond1 = diamond1.calculateDimension(stringBounder);
 				final Snake small = Snake.create(color);
 				small.addPoint(p1);
@@ -242,7 +242,7 @@ public class FtileIfWithLinks extends FtileIfWithDiamonds {
 			final Direction newDirection = Direction.leftOrRight(mp1a, mp2b);
 			final UPolygon arrow = x2 > x1 ? Arrows.asToRight() : Arrows.asToLeft();
 			if (originalDirection == newDirection) {
-				final double delta = (x2 > x1 ? -1 : 1) * 1.5 * Diamond.diamondHalfSize;
+				final double delta = (x2 > x1 ? -1 : 1) * 1.5 * Hexagon.hexagonHalfSize;
 				final Point2D mp2bc = new Point2D.Double(mp2b.getX() + delta, mp2b.getY());
 				final Snake snake = Snake.create(myArrowColor).withMerge(MergeStrategy.LIMITED);
 				final double middle = (mp1a.getY() + mp2b.getY()) / 2.0;
@@ -257,9 +257,9 @@ public class FtileIfWithLinks extends FtileIfWithDiamonds {
 				small.addPoint(mp2b);
 				ug.draw(small);
 			} else {
-				final double delta = (x2 > x1 ? -1 : 1) * 1.5 * Diamond.diamondHalfSize;
+				final double delta = (x2 > x1 ? -1 : 1) * 1.5 * Hexagon.hexagonHalfSize;
 				final Point2D mp2bb = new Point2D.Double(mp2b.getX() + delta,
-						mp2b.getY() - 1.5 * Diamond.diamondHalfSize);
+						mp2b.getY() - 1.5 * Hexagon.hexagonHalfSize);
 				final Snake snake = Snake.create(myArrowColor).withMerge(MergeStrategy.LIMITED);
 				snake.addPoint(mp1a);
 				snake.addPoint(mp1a.getX(), mp2bb.getY());
@@ -325,7 +325,7 @@ public class FtileIfWithLinks extends FtileIfWithDiamonds {
 				return;
 			}
 			final Point2D p1 = geo.translate(translate(stringBounder)).getPointOut();
-			final Point2D p2 = new Point2D.Double(dimTotal.getLeft(), dimTotal.getHeight() - Diamond.diamondHalfSize);
+			final Point2D p2 = new Point2D.Double(dimTotal.getLeft(), dimTotal.getHeight() - Hexagon.hexagonHalfSize);
 
 			final Point2D mp1a = translate1.getTranslated(p1);
 			final Point2D mp2b = translate2.getTranslated(p2);
