@@ -42,6 +42,7 @@ import java.util.Objects;
 import java.util.Set;
 
 import net.sourceforge.plantuml.ISkinParam;
+import net.sourceforge.plantuml.UseStyle;
 import net.sourceforge.plantuml.activitydiagram3.ftile.AbstractFtile;
 import net.sourceforge.plantuml.activitydiagram3.ftile.Ftile;
 import net.sourceforge.plantuml.activitydiagram3.ftile.FtileGeometry;
@@ -49,6 +50,10 @@ import net.sourceforge.plantuml.activitydiagram3.ftile.Swimlane;
 import net.sourceforge.plantuml.graphic.StringBounder;
 import net.sourceforge.plantuml.graphic.TextBlock;
 import net.sourceforge.plantuml.graphic.TextBlockUtils;
+import net.sourceforge.plantuml.style.PName;
+import net.sourceforge.plantuml.style.SName;
+import net.sourceforge.plantuml.style.Style;
+import net.sourceforge.plantuml.style.StyleSignature;
 import net.sourceforge.plantuml.ugraphic.UGraphic;
 import net.sourceforge.plantuml.ugraphic.URectangle;
 import net.sourceforge.plantuml.ugraphic.UTranslate;
@@ -82,17 +87,27 @@ public class FtileBlackBlock extends AbstractFtile {
 	@Override
 	protected FtileGeometry calculateDimensionFtile(StringBounder stringBounder) {
 		double supp = label.calculateDimension(stringBounder).getWidth();
-		if (supp > 0) {
+		if (supp > 0)
 			supp += labelMargin;
-		}
+
 		return new FtileGeometry(width + supp, height, width / 2, 0, height);
 	}
 
+	private StyleSignature getDefaultStyleDefinitionBar() {
+		return StyleSignature.of(SName.root, SName.element, SName.activityBar);
+	}
+
 	public void drawU(UGraphic ug) {
 		final URectangle rect = new URectangle(width, height).rounded(5).ignoreForCompressionOnX();
-		if (skinParam().shadowing(null)) {
-			rect.setDeltaShadow(3);
+		if (UseStyle.useBetaStyle()) {
+			final Style style = getDefaultStyleDefinitionBar().getMergedStyle(skinParam().getCurrentStyleBuilder());
+			final double shadowing = style.value(PName.Shadowing).asDouble();
+			rect.setDeltaShadow(shadowing);
+		} else {
+			if (skinParam().shadowing(null))
+				rect.setDeltaShadow(3);
 		}
+
 		ug.apply(colorBar).apply(colorBar.bg()).draw(rect);
 		final Dimension2D dimLabel = label.calculateDimension(ug.getStringBounder());
 		label.drawU(ug.apply(new UTranslate(width + labelMargin, -dimLabel.getHeight() / 2)));
