@@ -2,7 +2,7 @@
  * PlantUML : a free UML diagram generator
  * ========================================================================
  *
- * (C) Copyright 2009-2017, Arnaud Roques
+ * (C) Copyright 2009-2020, Arnaud Roques
  *
  * Project Info:  http://plantuml.com
  * 
@@ -36,91 +36,54 @@
 package net.sourceforge.plantuml.activitydiagram3.ftile.vertical;
 
 import java.awt.geom.Dimension2D;
-import java.util.Collections;
-import java.util.Set;
 
 import net.sourceforge.plantuml.Dimension2DDouble;
 import net.sourceforge.plantuml.ISkinParam;
-import net.sourceforge.plantuml.activitydiagram3.ftile.AbstractFtile;
-import net.sourceforge.plantuml.activitydiagram3.ftile.Diamond;
 import net.sourceforge.plantuml.activitydiagram3.ftile.FtileGeometry;
+import net.sourceforge.plantuml.activitydiagram3.ftile.Hexagon;
 import net.sourceforge.plantuml.activitydiagram3.ftile.Swimlane;
-import net.sourceforge.plantuml.graphic.HtmlColor;
 import net.sourceforge.plantuml.graphic.StringBounder;
 import net.sourceforge.plantuml.graphic.TextBlock;
 import net.sourceforge.plantuml.graphic.TextBlockUtils;
-import net.sourceforge.plantuml.ugraphic.UChangeBackColor;
-import net.sourceforge.plantuml.ugraphic.UChangeColor;
 import net.sourceforge.plantuml.ugraphic.UGraphic;
 import net.sourceforge.plantuml.ugraphic.UTranslate;
+import net.sourceforge.plantuml.ugraphic.color.HColor;
 
-public class FtileDiamondInside2 extends AbstractFtile {
+public class FtileDiamondInside2 extends FtileDiamondWIP {
 
-	private final HtmlColor backColor;
-	private final HtmlColor borderColor;
-	private final Swimlane swimlane;
-	private final TextBlock label;
-	private final TextBlock west;
-	private final TextBlock east;
-	private final TextBlock north;
-	private final TextBlock south;
-
-	public FtileDiamondInside2(ISkinParam skinParam, HtmlColor backColor, HtmlColor borderColor, Swimlane swimlane,
-			TextBlock label) {
-		this(skinParam, backColor, borderColor, swimlane, label, TextBlockUtils.empty(0, 0),
-				TextBlockUtils.empty(0, 0), TextBlockUtils.empty(0, 0), TextBlockUtils.empty(0, 0));
+	public FtileDiamondInside2(TextBlock label, ISkinParam skinParam, HColor backColor, HColor borderColor,
+			Swimlane swimlane) {
+		this(label, skinParam, backColor, borderColor, swimlane, TextBlockUtils.empty(0, 0), TextBlockUtils.empty(0, 0),
+				TextBlockUtils.empty(0, 0), TextBlockUtils.empty(0, 0));
 	}
 
 	public FtileDiamondInside2 withNorth(TextBlock north) {
-		return new FtileDiamondInside2(skinParam(), backColor, borderColor, swimlane, label, north, south, west, east);
+		return new FtileDiamondInside2(label, skinParam(), backColor, borderColor, swimlane, north, south, west, east);
 	}
 
 	public FtileDiamondInside2 withWest(TextBlock west) {
-		return new FtileDiamondInside2(skinParam(), backColor, borderColor, swimlane, label, north, south, west, east);
+		return new FtileDiamondInside2(label, skinParam(), backColor, borderColor, swimlane, north, south, west, east);
 	}
 
 	public FtileDiamondInside2 withEast(TextBlock east) {
-		return new FtileDiamondInside2(skinParam(), backColor, borderColor, swimlane, label, north, south, west, east);
+		return new FtileDiamondInside2(label, skinParam(), backColor, borderColor, swimlane, north, south, west, east);
 	}
 
 	public FtileDiamondInside2 withSouth(TextBlock south) {
-		return new FtileDiamondInside2(skinParam(), backColor, borderColor, swimlane, label, north, south, west, east);
+		return new FtileDiamondInside2(label, skinParam(), backColor, borderColor, swimlane, north, south, west, east);
 	}
 
-	private FtileDiamondInside2(ISkinParam skinParam, HtmlColor backColor, HtmlColor borderColor, Swimlane swimlane,
-			TextBlock label, TextBlock north, TextBlock south, TextBlock west, TextBlock east) {
-		super(skinParam);
-		this.backColor = backColor;
-		this.swimlane = swimlane;
-		this.borderColor = borderColor;
-		this.label = label;
-		this.west = west;
-		this.east = east;
-		this.north = north;
-		this.south = south;
-	}
-
-	public Set<Swimlane> getSwimlanes() {
-		if (swimlane == null) {
-			return Collections.emptySet();
-		}
-		return Collections.singleton(swimlane);
-	}
-
-	public Swimlane getSwimlaneIn() {
-		return swimlane;
-	}
-
-	public Swimlane getSwimlaneOut() {
-		return swimlane;
+	private FtileDiamondInside2(TextBlock label, ISkinParam skinParam, HColor backColor, HColor borderColor,
+			Swimlane swimlane, TextBlock north, TextBlock south, TextBlock west, TextBlock east) {
+		super(label, skinParam, backColor, borderColor, swimlane, north, south, east, west);
 	}
 
 	public void drawU(UGraphic ug) {
 		final StringBounder stringBounder = ug.getStringBounder();
 		final Dimension2D dimLabel = label.calculateDimension(stringBounder);
 		final Dimension2D dimTotal = calculateDimensionAlone(stringBounder);
-		ug = ug.apply(new UChangeColor(borderColor)).apply(getThickness()).apply(new UChangeBackColor(backColor));
-		ug.draw(Diamond.asPolygon(skinParam().shadowing(), dimTotal.getWidth(), dimTotal.getHeight()));
+		ug = ug.apply(borderColor).apply(getThickness()).apply(backColor.bg());
+		ug.draw(Hexagon.asPolygon(shadowing, dimTotal.getWidth(), dimTotal.getHeight()));
 
 		north.drawU(ug.apply(new UTranslate(4 + dimTotal.getWidth() / 2, dimTotal.getHeight())));
 		south.drawU(ug.apply(new UTranslate(4 + dimTotal.getWidth() / 2, dimTotal.getHeight())));
@@ -141,11 +104,11 @@ public class FtileDiamondInside2 extends AbstractFtile {
 		final Dimension2D dimLabel = label.calculateDimension(stringBounder);
 		final Dimension2D dim;
 		if (dimLabel.getWidth() == 0 || dimLabel.getHeight() == 0) {
-			dim = new Dimension2DDouble(Diamond.diamondHalfSize * 2, Diamond.diamondHalfSize * 2);
+			dim = new Dimension2DDouble(Hexagon.hexagonHalfSize * 2, Hexagon.hexagonHalfSize * 2);
 		} else {
 			dim = Dimension2DDouble.delta(
-					Dimension2DDouble.atLeast(dimLabel, Diamond.diamondHalfSize * 2, Diamond.diamondHalfSize * 2),
-					Diamond.diamondHalfSize * 2, 0);
+					Dimension2DDouble.atLeast(dimLabel, Hexagon.hexagonHalfSize * 2, Hexagon.hexagonHalfSize * 2),
+					Hexagon.hexagonHalfSize * 2, 0);
 		}
 		return new FtileGeometry(dim, dim.getWidth() / 2, 0, dim.getHeight());
 	}
