@@ -39,7 +39,6 @@ import java.awt.geom.Dimension2D;
 import java.util.Arrays;
 import java.util.Collection;
 import java.util.List;
-import java.util.ListIterator;
 
 import net.sourceforge.plantuml.Dimension2DDouble;
 import net.sourceforge.plantuml.activitydiagram3.Branch;
@@ -51,7 +50,6 @@ import net.sourceforge.plantuml.style.SName;
 import net.sourceforge.plantuml.style.StyleSignature;
 import net.sourceforge.plantuml.ugraphic.UGraphic;
 import net.sourceforge.plantuml.ugraphic.UTranslate;
-import net.sourceforge.plantuml.utils.MathUtils;
 
 public class GtileIfHexagon extends GtileColumns {
 
@@ -67,13 +65,17 @@ public class GtileIfHexagon extends GtileColumns {
 		return "GtileIfHexagon " + gtiles;
 	}
 
+	public static Gtile build(Swimlane swimlane, List<Gtile> gtiles, List<Branch> branches) {
+		final GtileIfHexagon result = new GtileIfHexagon(swimlane, gtiles, branches);
+		return result;
+		// return Gtiles.withEastMargin(result, 0);
+	}
+
 	// ConditionalBuilder
 	// FtileFactoryDelegatorIf
 
-	public GtileIfHexagon(Swimlane swimlane, List<Gtile> gtiles, List<Branch> branches) {
-		super(gtiles, swimlane);
-		if (branches.size() <= 1)
-			throw new IllegalArgumentException();
+	private GtileIfHexagon(Swimlane swimlane, List<Gtile> gtiles, List<Branch> branches) {
+		super(gtiles, swimlane, 20);
 
 		this.branches = branches;
 
@@ -81,17 +83,54 @@ public class GtileIfHexagon extends GtileColumns {
 		this.shape2 = Gtiles.diamondEmpty(swimlane, getStringBounder(), skinParam(), getDefaultStyleDefinitionDiamond(),
 				branches.get(0).getColor());
 
-		final double height1 = shape1.calculateDimension(stringBounder).getHeight();
+		final Dimension2D dimShape1 = shape1.calculateDimension(stringBounder);
+		this.pushDown(dimShape1.getHeight());
 
-		for (ListIterator<UTranslate> it = positions.listIterator(); it.hasNext();) {
-			final UTranslate tmp = it.next();
-			it.set(tmp.compose(UTranslate.dy(height1)));
+		final double posShape;
+		final Dimension2D totalDim;
+		if (branches.size() == 2) {
+			final Gtile tile0 = branches.get(0).getGtile();
+			final Gtile tile1 = branches.get(1).getGtile();
+
+			final double northHook0 = tile0.getGPoint(GPoint.NORTH_HOOK).getCoord().getDx();
+			final double width0 = tile0.calculateDimension(getStringBounder()).getWidth();
+			final double northHook1 = tile1.getGPoint(GPoint.NORTH_HOOK).getCoord().getDx();
+			final double width1 = tile1.calculateDimension(getStringBounder()).getWidth();
+
+			final double shlen1 = shape1.calculateDimension(getStringBounder()).getWidth();
+			final double shlen = shape1.getGPoint(GPoint.EAST_HOOK).getCoord().getDx()
+					- shape1.getGPoint(GPoint.WEST_HOOK).getCoord().getDx();
+
+			System.err.println("shlen=" + shlen);
+
+			System.err.println("northHook0=" + northHook0);
+			System.err.println("width0=" + width0);
+
+			System.err.println("northHook1=" + northHook1);
+			System.err.println("width1=" + width1);
+
+			final double alpha = northHook0;
+			final double beta = width1 - northHook1;
+			System.err.println("alpha=" + alpha);
+			System.err.println("beta=" + beta);
+
+			final double wantedWidth = alpha + shlen + beta;
+			System.err.println("wantedWidth=" + wantedWidth);
+			double diff = wantedWidth - width0 - width1;
+			if (diff < 0)
+				diff = 0;
+			System.err.println("diff=" + diff);
+			this.setMargin(diff + 10);
+			totalDim = calculateDimensionRaw(stringBounder);
+			final double p2 = totalDim.getWidth() - beta;
+			posShape = (alpha + p2) / 2;
+		} else {
+			totalDim = calculateDimensionRaw(stringBounder);
+			posShape = totalDim.getWidth() / 2;
 		}
 
-		final Dimension2D totalDim = calculateDimensionRaw(stringBounder);
-		this.positionShape1 = UTranslate.dx(totalDim.getWidth() / 2)
-				.compose(shape1.getCoord(GPoint.NORTH_BORDER).reverse());
-		this.positionShape2 = new UTranslate(totalDim.getWidth() / 2, totalDim.getHeight())
+		this.positionShape1 = UTranslate.dx(posShape).compose(shape1.getCoord(GPoint.NORTH_BORDER).reverse());
+		this.positionShape2 = new UTranslate(posShape, totalDim.getHeight())
 				.compose(shape2.getCoord(GPoint.SOUTH_BORDER).reverse());
 
 	}
@@ -108,22 +147,34 @@ public class GtileIfHexagon extends GtileColumns {
 	private Gtile getShape1(Swimlane swimlane) {
 		GtileHexagonInside tmp = Gtiles.hexagonInside(swimlane, getStringBounder(), skinParam(),
 				getDefaultStyleDefinitionDiamond(), branches.get(0).getColor(), branches.get(0).getLabelTest());
+
 		final TextBlock tmp0 = branches.get(0).getTextBlockPositive();
+		if (branches.size() == 1) {
+			return Gtiles.withSouthMargin(tmp.withSouthLabel(tmp0), 10);
+		}
+
 		final TextBlock tmp1 = branches.get(1).getTextBlockPositive();
 		return Gtiles.withSouthMargin(tmp.withWestLabel(tmp0).withEastLabel(tmp1), 10);
 	}
 
 	@Override
 	public Dimension2D calculateDimension(StringBounder stringBounder) {
-		final Dimension2D toto1 = calculateDimensionRaw(stringBounder);
-		final Dimension2D toto2 = shape1.calculateDimension(stringBounder);
-		return MathUtils.max(toto1, toto2);
+		final Dimension2D rawDim = calculateDimensionRaw(stringBounder);
+		if (branches.size() == 2) {
+			final Dimension2D shape1Dim = shape1.calculateDimension(stringBounder);
+			final double shape1max = this.positionShape1.getDx() + shape1Dim.getWidth();
+			return Dimension2DDouble.atLeast(rawDim, shape1max, 0);
+
+		}
+		// return MathUtils.max(rawDim, shape1Dim);
+		return rawDim;
 	}
 
 	private Dimension2D calculateDimensionRaw(StringBounder stringBounder) {
 		final double height2 = shape2.calculateDimension(stringBounder).getHeight();
 		final Dimension2D nude = super.calculateDimension(stringBounder);
-		return Dimension2DDouble.delta(nude, 0, height2);
+		// +30 to be done only when branches.size()==1 ?
+		return Dimension2DDouble.delta(nude, 0, height2 + 30);
 	}
 
 	final public StyleSignature getDefaultStyleDefinitionActivity() {
@@ -163,18 +214,25 @@ public class GtileIfHexagon extends GtileColumns {
 
 	@Override
 	public Collection<GConnection> getInnerConnections() {
-		if (branches.size() == 2) {
+		if (branches.size() == 1) {
+			final GConnection arrow1 = new GConnectionVerticalDown(positionShape1, shape1.getGPoint(GPoint.SOUTH_HOOK),
+					getPosition(0), gtiles.get(0).getGPoint(GPoint.NORTH_HOOK), TextBlockUtils.EMPTY_TEXT_BLOCK);
+			final GConnection arrow2 = new GConnectionVerticalDown(getPosition(0),
+					gtiles.get(0).getGPoint(GPoint.SOUTH_HOOK), positionShape2, shape2.getGPoint(GPoint.NORTH_HOOK),
+					TextBlockUtils.EMPTY_TEXT_BLOCK);
+			return Arrays.asList(arrow1, arrow2);
+		} else if (branches.size() == 2) {
 			final GConnection arrow1 = new GConnectionHorizontalThenVerticalDown(positionShape1,
-					shape1.getGPoint(GPoint.WEST_HOOK), positions.get(0), gtiles.get(0).getGPoint(GPoint.NORTH_HOOK),
+					shape1.getGPoint(GPoint.WEST_HOOK), getPosition(0), gtiles.get(0).getGPoint(GPoint.NORTH_HOOK),
 					TextBlockUtils.EMPTY_TEXT_BLOCK);
 			final GConnection arrow2 = new GConnectionHorizontalThenVerticalDown(positionShape1,
-					shape1.getGPoint(GPoint.EAST_HOOK), positions.get(1), gtiles.get(1).getGPoint(GPoint.NORTH_HOOK),
+					shape1.getGPoint(GPoint.EAST_HOOK), getPosition(1), gtiles.get(1).getGPoint(GPoint.NORTH_HOOK),
 					TextBlockUtils.EMPTY_TEXT_BLOCK);
 
-			final GConnection arrow3 = new GConnectionVerticalDownThenHorizontal(positions.get(0),
+			final GConnection arrow3 = new GConnectionVerticalDownThenHorizontal(getPosition(0),
 					gtiles.get(0).getGPoint(GPoint.SOUTH_HOOK), positionShape2, shape2.getGPoint(GPoint.WEST_HOOK),
 					TextBlockUtils.EMPTY_TEXT_BLOCK);
-			final GConnection arrow4 = new GConnectionVerticalDownThenHorizontal(positions.get(1),
+			final GConnection arrow4 = new GConnectionVerticalDownThenHorizontal(getPosition(1),
 					gtiles.get(1).getGPoint(GPoint.SOUTH_HOOK), positionShape2, shape2.getGPoint(GPoint.EAST_HOOK),
 					TextBlockUtils.EMPTY_TEXT_BLOCK);
 
