@@ -244,18 +244,19 @@ public class PlantUmlTask extends Task {
 			this.log(s);
 			throw new BuildException(s);
 		}
-		for (File f : dir.listFiles()) {
-			if (f.isFile() == false) {
-				continue;
+		if (dir.listFiles() != null)
+			for (File f : dir.listFiles()) {
+				if (f.isFile() == false)
+					continue;
+
+				if (fileToProcess(f.getName()) == false)
+					continue;
+
+				final boolean error = processingSingleFile(f);
+				if (error)
+					return f;
+
 			}
-			if (fileToProcess(f.getName()) == false) {
-				continue;
-			}
-			final boolean error = processingSingleFile(f);
-			if (error) {
-				return f;
-			}
-		}
 		return null;
 	}
 
