@@ -40,7 +40,10 @@ import java.awt.geom.Rectangle2D;
 import net.sourceforge.plantuml.ColorParam;
 import net.sourceforge.plantuml.ISkinParam;
 import net.sourceforge.plantuml.SkinParamUtils;
+import net.sourceforge.plantuml.UseStyle;
 import net.sourceforge.plantuml.activitydiagram3.ftile.BoxStyle;
+import net.sourceforge.plantuml.activitydiagram3.ftile.Ftile;
+import net.sourceforge.plantuml.activitydiagram3.ftile.Swimlane;
 import net.sourceforge.plantuml.activitydiagram3.ftile.vertical.FtileBox;
 import net.sourceforge.plantuml.activitydiagram3.ftile.vertical.FtileCircleStart;
 import net.sourceforge.plantuml.activitydiagram3.ftile.vertical.FtileDiamond;
@@ -50,6 +53,10 @@ import net.sourceforge.plantuml.graphic.HorizontalAlignment;
 import net.sourceforge.plantuml.graphic.InnerStrategy;
 import net.sourceforge.plantuml.graphic.StringBounder;
 import net.sourceforge.plantuml.graphic.TextBlock;
+import net.sourceforge.plantuml.style.PName;
+import net.sourceforge.plantuml.style.SName;
+import net.sourceforge.plantuml.style.Style;
+import net.sourceforge.plantuml.style.StyleSignature;
 import net.sourceforge.plantuml.ugraphic.MinMax;
 import net.sourceforge.plantuml.ugraphic.UFont;
 import net.sourceforge.plantuml.ugraphic.UGraphic;
@@ -111,7 +118,7 @@ public class BpmElement extends AbstractConnectorPuzzle implements ConnectorPuzz
 			public Dimension2D calculateDimension(StringBounder stringBounder) {
 				return raw.calculateDimension(stringBounder);
 			}
-			
+
 			public MinMax getMinMax(StringBounder stringBounder) {
 				return raw.getMinMax(stringBounder);
 			}
@@ -135,9 +142,20 @@ public class BpmElement extends AbstractConnectorPuzzle implements ConnectorPuzz
 		}
 	}
 
+	private StyleSignature getSignatureCircle() {
+		return StyleSignature.of(SName.root, SName.element, SName.activityDiagram, SName.circle);
+	}
+
+	private Style getStyle(ISkinParam skinParam) {
+		if (UseStyle.useBetaStyle())
+			return getSignatureCircle().getMergedStyle(skinParam.getCurrentStyleBuilder());
+
+		return null;
+	}
+
 	public TextBlock toTextBlockInternal(ISkinParam skinParam) {
 		if (type == BpmElementType.START) {
-			return new FtileCircleStart(skinParam, HColorUtils.BLACK, null, null);
+			return new FtileCircleStart(skinParam, HColorUtils.BLACK, null, getStyle(skinParam));
 		}
 		if (type == BpmElementType.MERGE) {
 			final HColor borderColor = SkinParamUtils.getColor(skinParam, null, ColorParam.activityBorder);
