@@ -242,7 +242,7 @@ public final class CommandFactoryNoteOnEntity implements SingleMultiFactoryComma
 
 		final String stereotypeString = line0.get("STEREO", 0);
 		if (stereotypeString != null) {
-			final Stereotype stereotype = new Stereotype(stereotypeString);
+			final Stereotype stereotype = Stereotype.build(stereotypeString);
 			colors = colors.applyStereotypeForNote(stereotype, diagram.getSkinParam(), FontParam.NOTE,
 					ColorParam.noteBackground, ColorParam.noteBorder);
 			note.setStereotype(stereotype);
