@@ -2,7 +2,7 @@
  * PlantUML : a free UML diagram generator
  * ========================================================================
  *
- * (C) Copyright 2009-2017, Arnaud Roques
+ * (C) Copyright 2009-2020, Arnaud Roques
  *
  * Project Info:  http://plantuml.com
  * 
@@ -36,27 +36,36 @@
 package net.sourceforge.plantuml.cucadiagram;
 
 import java.awt.geom.Dimension2D;
+import java.util.Objects;
 
 import net.sourceforge.plantuml.Hideable;
 import net.sourceforge.plantuml.ISkinSimple;
+import net.sourceforge.plantuml.LineLocation;
 import net.sourceforge.plantuml.OptionFlags;
 import net.sourceforge.plantuml.Removeable;
+import net.sourceforge.plantuml.UmlDiagramType;
 import net.sourceforge.plantuml.Url;
 import net.sourceforge.plantuml.command.Position;
 import net.sourceforge.plantuml.graphic.FontConfiguration;
 import net.sourceforge.plantuml.graphic.HorizontalAlignment;
-import net.sourceforge.plantuml.graphic.HtmlColor;
-import net.sourceforge.plantuml.graphic.HtmlColorSet;
 import net.sourceforge.plantuml.graphic.StringBounder;
 import net.sourceforge.plantuml.graphic.TextBlock;
 import net.sourceforge.plantuml.graphic.USymbolInterface;
 import net.sourceforge.plantuml.graphic.color.Colors;
+import net.sourceforge.plantuml.skin.VisibilityModifier;
+import net.sourceforge.plantuml.style.StyleBuilder;
 import net.sourceforge.plantuml.svek.Bibliotekon;
+import net.sourceforge.plantuml.ugraphic.UComment;
 import net.sourceforge.plantuml.ugraphic.UFont;
+import net.sourceforge.plantuml.ugraphic.color.HColor;
 import net.sourceforge.plantuml.utils.UniqueSequence;
 
 public class Link extends WithLinkType implements Hideable, Removeable {
 
+	public final StyleBuilder getStyleBuilder() {
+		return styleBuilder;
+	}
+
 	final private IEntity cl1;
 	final private IEntity cl2;
 
@@ -83,45 +92,62 @@ public class Link extends WithLinkType implements Hideable, Removeable {
 
 	private boolean constraint = true;
 	private boolean inverted = false;
-	private LinkArrow linkArrow = LinkArrow.NONE;
+	private LinkArrow linkArrow = LinkArrow.NONE_OR_SEVERAL;
 
 	private boolean opale;
 	private boolean horizontalSolitary;
 	private String sametail;
+	private VisibilityModifier visibilityModifier;
+	private final StyleBuilder styleBuilder;
+	private Stereotype stereotype;
 
 	private Url url;
 
-	public Link(IEntity cl1, IEntity cl2, LinkType type, Display label, int length) {
-		this(cl1, cl2, type, label, length, null, null, null, null, null);
+	public String idCommentForSvg() {
+		if (type.looksLikeRevertedForSvg())
+			return getEntity1().getCodeGetName() + "-backto-" + getEntity2().getCodeGetName();
+
+		if (type.looksLikeNoDecorAtAllSvg())
+			return getEntity1().getCodeGetName() + "-" + getEntity2().getCodeGetName();
+
+		return getEntity1().getCodeGetName() + "-to-" + getEntity2().getCodeGetName();
+	}
+
+	public UComment commentForSvg() {
+		if (type.looksLikeRevertedForSvg())
+			return new UComment(
+					"reverse link " + getEntity1().getCodeGetName() + " to " + getEntity2().getCodeGetName());
+
+		return new UComment("link " + getEntity1().getCodeGetName() + " to " + getEntity2().getCodeGetName());
+	}
+
+	public Link(IEntity cl1, IEntity cl2, LinkType type, Display label, int length, StyleBuilder styleBuilder) {
+		this(cl1, cl2, type, label, length, null, null, null, null, null, styleBuilder);
 	}
 
 	public Link(IEntity cl1, IEntity cl2, LinkType type, Display label, int length, String qualifier1,
-			String qualifier2, String labeldistance, String labelangle) {
-		this(cl1, cl2, type, label, length, qualifier1, qualifier2, labeldistance, labelangle, null);
+			String qualifier2, String labeldistance, String labelangle, StyleBuilder styleBuilder) {
+		this(cl1, cl2, type, label, length, qualifier1, qualifier2, labeldistance, labelangle, null, styleBuilder);
 	}
 
 	public Link(IEntity cl1, IEntity cl2, LinkType type, Display label, int length, String qualifier1,
-			String qualifier2, String labeldistance, String labelangle, HtmlColor specificColor) {
+			String qualifier2, String labeldistance, String labelangle, HColor specificColor,
+			StyleBuilder styleBuilder) {
 		if (length < 1) {
 			throw new IllegalArgumentException();
 		}
-		if (cl1 == null) {
-			throw new IllegalArgumentException();
-		}
-		if (cl2 == null) {
-			throw new IllegalArgumentException();
-		}
-
-		this.cl1 = cl1;
-		this.cl2 = cl2;
+		this.styleBuilder = styleBuilder;
+		this.cl1 = Objects.requireNonNull(cl1);
+		this.cl2 = Objects.requireNonNull(cl2);
 		this.type = type;
 		if (Display.isNull(label)) {
 			this.label = Display.NULL;
-			// } else if (doWeHaveToRemoveUrlAtStart(label)) {
-			// this.url = label.initUrl();
-			// this.label = label.removeHeadingUrl(url).manageGuillemet();
 		} else {
 			this.label = label.manageGuillemet();
+			if (VisibilityModifier.isVisibilityCharacter(label.get(0))) {
+				visibilityModifier = VisibilityModifier.getVisibilityModifier(label.get(0), false);
+			}
+
 		}
 		this.length = length;
 		this.qualifier1 = qualifier1;
@@ -129,39 +155,24 @@ public class Link extends WithLinkType implements Hideable, Removeable {
 		this.labeldistance = labeldistance;
 		this.labelangle = labelangle;
 		this.setSpecificColor(specificColor);
-		if (qualifier1 != null) {
+		if (qualifier1 != null)
 			((ILeaf) cl1).setNearDecoration(true);
-		}
-		if (qualifier2 != null) {
+
+		if (qualifier2 != null)
 			((ILeaf) cl2).setNearDecoration(true);
-		}
-		// if (type.getDecor2() == LinkDecor.EXTENDS) {
-		// setSametail(cl1.getUid());
-		// }
+
 	}
 
-	// private static boolean doWeHaveToRemoveUrlAtStart(Display label) {
-	// if (label.size() == 0) {
-	// return false;
-	// }
-	// final String s = label.get(0).toString();
-	// if (s.matches("^\\[\\[\\S+\\]\\].+$")) {
-	// return true;
-	// }
-	// return false;
-	// }
-
 	public Link getInv() {
-		// if (getLength() == 1) {
-		// final int x = cl1.getXposition();
-		// cl2.setXposition(x-1);
-		// }
 		final Link result = new Link(cl2, cl1, getType().getInversed(), label, length, qualifier2, qualifier1,
-				labeldistance, labelangle, getSpecificColor());
+				labeldistance, labelangle, getSpecificColor(), styleBuilder);
 		result.inverted = !this.inverted;
 		result.port1 = this.port2;
 		result.port2 = this.port1;
 		result.url = this.url;
+		result.linkConstraint = this.linkConstraint;
+		result.stereotype = stereotype;
+		result.visibilityModifier = visibilityModifier;
 		return result;
 	}
 
@@ -185,9 +196,9 @@ public class Link extends WithLinkType implements Hideable, Removeable {
 	}
 
 	public final boolean isInvis() {
-		if (type.isInvisible()) {
+		if (type.isInvisible())
 			return true;
-		}
+
 		return invis;
 	}
 
@@ -196,12 +207,12 @@ public class Link extends WithLinkType implements Hideable, Removeable {
 	}
 
 	public boolean isBetween(IEntity cl1, IEntity cl2) {
-		if (cl1.equals(this.cl1) && cl2.equals(this.cl2)) {
+		if (cl1.equals(this.cl1) && cl2.equals(this.cl2))
 			return true;
-		}
-		if (cl1.equals(this.cl2) && cl2.equals(this.cl1)) {
+
+		if (cl1.equals(this.cl2) && cl2.equals(this.cl1))
 			return true;
-		}
+
 		return false;
 	}
 
@@ -219,49 +230,49 @@ public class Link extends WithLinkType implements Hideable, Removeable {
 	}
 
 	public EntityPort getEntityPort1(Bibliotekon bibliotekon) {
-		return new EntityPort(bibliotekon.getShapeUid((ILeaf) cl1), port1);
+		return new EntityPort(bibliotekon.getNodeUid((ILeaf) cl1), port1);
 	}
 
 	public EntityPort getEntityPort2(Bibliotekon bibliotekon) {
-		return new EntityPort(bibliotekon.getShapeUid((ILeaf) cl2), port2);
+		return new EntityPort(bibliotekon.getNodeUid((ILeaf) cl2), port2);
 	}
 
 	@Override
 	public LinkType getType() {
-		if (opale) {
+		if (opale)
 			return new LinkType(LinkDecor.NONE, LinkDecor.NONE);
-		}
-		if (getSametail() != null) {
+
+		if (getSametail() != null)
 			return new LinkType(LinkDecor.NONE, LinkDecor.NONE);
-		}
+
 		LinkType result = type;
 		if (OptionFlags.USE_INTERFACE_EYE1) {
-			if (isLollipopInterfaceEye(cl1)) {
+			if (isLollipopInterfaceEye(cl1))
 				type = type.withLollipopInterfaceEye1();
-			}
-			if (isLollipopInterfaceEye(cl2)) {
+
+			if (isLollipopInterfaceEye(cl2))
 				type = type.withLollipopInterfaceEye2();
-			}
+
 		}
 		return result;
 	}
 
 	private boolean isReallyGroup(IEntity ent) {
-		if (ent.isGroup() == false) {
+		if (ent.isGroup() == false)
 			return false;
-		}
+
 		final IGroup group = (IGroup) ent;
 		return group.getChildren().size() + group.getLeafsDirect().size() > 0;
 	}
 
 	public LinkType getTypePatchCluster() {
 		LinkType result = getType();
-		if (isReallyGroup(getEntity1())) {
+		if (isReallyGroup(getEntity1()))
 			result = result.withoutDecors2();
-		}
-		if (isReallyGroup(getEntity2())) {
+
+		if (isReallyGroup(getEntity2()))
 			result = result.withoutDecors1();
-		}
+
 		return result;
 	}
 
@@ -271,12 +282,12 @@ public class Link extends WithLinkType implements Hideable, Removeable {
 		}
 		LinkType result = type;
 		if (OptionFlags.USE_INTERFACE_EYE1) {
-			if (isLollipopInterfaceEye(cl1)) {
+			if (isLollipopInterfaceEye(cl1))
 				type = type.withLollipopInterfaceEye1();
-			}
-			if (isLollipopInterfaceEye(cl2)) {
+
+			if (isLollipopInterfaceEye(cl2))
 				type = type.withLollipopInterfaceEye2();
-			}
+
 		}
 		return result;
 	}
@@ -344,39 +355,39 @@ public class Link extends WithLinkType implements Hideable, Removeable {
 	}
 
 	public boolean isAutoLinkOfAGroup() {
-		if (getEntity1().isGroup() == false) {
+		if (getEntity1().isGroup() == false)
 			return false;
-		}
-		if (getEntity2().isGroup() == false) {
+
+		if (getEntity2().isGroup() == false)
 			return false;
-		}
-		if (getEntity1() == getEntity2()) {
+
+		if (getEntity1() == getEntity2())
 			return true;
-		}
+
 		return false;
 	}
 
 	public boolean containsType(LeafType type) {
-		if (getEntity1().getLeafType() == type || getEntity2().getLeafType() == type) {
+		if (getEntity1().getLeafType() == type || getEntity2().getLeafType() == type)
 			return true;
-		}
+
 		return false;
 	}
 
 	public boolean contains(IEntity entity) {
-		if (getEntity1() == entity || getEntity2() == entity) {
+		if (getEntity1() == entity || getEntity2() == entity)
 			return true;
-		}
+
 		return false;
 	}
 
 	public IEntity getOther(IEntity entity) {
-		if (getEntity1() == entity) {
+		if (getEntity1() == entity)
 			return getEntity2();
-		}
-		if (getEntity2() == entity) {
+
+		if (getEntity2() == entity)
 			return getEntity1();
-		}
+
 		throw new IllegalArgumentException();
 	}
 
@@ -424,9 +435,9 @@ public class Link extends WithLinkType implements Hideable, Removeable {
 	}
 
 	public final LinkArrow getLinkArrow() {
-		if (inverted) {
+		if (inverted)
 			return linkArrow.reverse();
-		}
+
 		return linkArrow;
 	}
 
@@ -440,7 +451,8 @@ public class Link extends WithLinkType implements Hideable, Removeable {
 
 	public boolean hasEntryPoint() {
 		return (getEntity1().isGroup() == false && ((ILeaf) getEntity1()).getEntityPosition() != EntityPosition.NORMAL)
-				|| (getEntity2().isGroup() == false && ((ILeaf) getEntity2()).getEntityPosition() != EntityPosition.NORMAL);
+				|| (getEntity2().isGroup() == false
+						&& ((ILeaf) getEntity2()).getEntityPosition() != EntityPosition.NORMAL);
 	}
 
 	public boolean hasTwoEntryPointsSameContainer() {
@@ -463,28 +475,28 @@ public class Link extends WithLinkType implements Hideable, Removeable {
 	}
 
 	public boolean sameConnections(Link other) {
-		if (this.cl1 == other.cl1 && this.cl2 == other.cl2) {
+		if (this.cl1 == other.cl1 && this.cl2 == other.cl2)
 			return true;
-		}
-		if (this.cl1 == other.cl2 && this.cl2 == other.cl1) {
+
+		if (this.cl1 == other.cl2 && this.cl2 == other.cl1)
 			return true;
-		}
+
 		return false;
 	}
 
 	public boolean doesTouch(Link other) {
-		if (this.cl1 == other.cl1) {
+		if (this.cl1 == other.cl1)
 			return true;
-		}
-		if (this.cl1 == other.cl2) {
+
+		if (this.cl1 == other.cl2)
 			return true;
-		}
-		if (this.cl2 == other.cl1) {
+
+		if (this.cl2 == other.cl1)
 			return true;
-		}
-		if (this.cl2 == other.cl2) {
+
+		if (this.cl2 == other.cl2)
 			return true;
-		}
+
 		return false;
 	}
 
@@ -497,9 +509,9 @@ public class Link extends WithLinkType implements Hideable, Removeable {
 	}
 
 	public boolean hasUrl() {
-		if (Display.isNull(label) == false && label.hasUrl()) {
+		if (Display.isNull(label) == false && label.hasUrl())
 			return true;
-		}
+
 		return getUrl() != null;
 	}
 
@@ -514,12 +526,57 @@ public class Link extends WithLinkType implements Hideable, Removeable {
 	public void setPortMembers(String port1, String port2) {
 		this.port1 = port1;
 		this.port2 = port2;
-		if (port1 != null) {
+		if (port1 != null)
 			((ILeaf) cl1).addPortShortName(port1);
-		}
-		if (port2 != null) {
+
+		if (port2 != null)
 			((ILeaf) cl2).addPortShortName(port2);
-		}
+
+	}
+
+	public final VisibilityModifier getVisibilityModifier() {
+		return visibilityModifier;
+	}
+
+	private UmlDiagramType umlType;
+
+	public void setUmlDiagramType(UmlDiagramType type) {
+		this.umlType = type;
+	}
+
+	public UmlDiagramType getUmlDiagramType() {
+		return umlType;
+	}
+
+	private LinkConstraint linkConstraint;
+
+	public void setLinkConstraint(LinkConstraint linkConstraint) {
+		this.linkConstraint = linkConstraint;
+	}
+
+	public final LinkConstraint getLinkConstraint() {
+		return linkConstraint;
+	}
+
+	private LineLocation codeLine;
+
+	public String getCodeLine() {
+		if (codeLine == null)
+			return null;
+
+		return "" + codeLine.getPosition();
+	}
+
+	public void setCodeLine(LineLocation location) {
+		this.codeLine = location;
+	}
+
+	public void setStereotype(Stereotype stereotype) {
+		this.stereotype = stereotype;
+	}
+
+	public final Stereotype getStereotype() {
+		return stereotype;
 	}
 
 }
