@@ -261,7 +261,7 @@ public class CucaDiagramFileMakerElk implements CucaDiagramFileMaker {
 			final double shadowing;
 			final UStroke stroke;
 			if (UseStyle.useBetaStyle()) {
-				final Style style = Cluster.getDefaultStyleDefinition(umlDiagramType.getStyleName())
+				final Style style = Cluster.getDefaultStyleDefinition(umlDiagramType.getStyleName(), group.getUSymbol())
 						.getMergedStyle(skinParam.getCurrentStyleBuilder());
 				shadowing = style.value(PName.Shadowing).asDouble();
 				stroke = Cluster.getStrokeInternal(group, skinParam, style);
@@ -275,8 +275,8 @@ public class CucaDiagramFileMakerElk implements CucaDiagramFileMaker {
 				stroke = Cluster.getStrokeInternal(group, skinParam, null);
 			}
 			HColor backColor = getBackColor(umlDiagramType);
-			backColor = Cluster.getBackColor(backColor, skinParam, group.getStereotype(),
-					umlDiagramType.getStyleName());
+			backColor = Cluster.getBackColor(backColor, skinParam, group.getStereotype(), umlDiagramType.getStyleName(),
+					group.getUSymbol());
 
 			final double roundCorner = group.getUSymbol() == null ? 0
 					: group.getUSymbol().getSkinParameter().getRoundCorner(skinParam, group.getStereotype());
