@@ -2,7 +2,7 @@
  * PlantUML : a free UML diagram generator
  * ========================================================================
  *
- * (C) Copyright 2009-2017, Arnaud Roques
+ * (C) Copyright 2009-2020, Arnaud Roques
  *
  * Project Info:  http://plantuml.com
  * 
@@ -43,17 +43,20 @@ import java.util.StringTokenizer;
 
 import net.sourceforge.plantuml.BackSlash;
 import net.sourceforge.plantuml.Log;
-import net.sourceforge.plantuml.graphic.HtmlColorGradient;
-import net.sourceforge.plantuml.ugraphic.ColorMapper;
+import net.sourceforge.plantuml.security.SecurityUtils;
 import net.sourceforge.plantuml.ugraphic.ShadowManager;
 import net.sourceforge.plantuml.ugraphic.UPath;
 import net.sourceforge.plantuml.ugraphic.USegment;
 import net.sourceforge.plantuml.ugraphic.USegmentType;
+import net.sourceforge.plantuml.ugraphic.color.ColorMapper;
+import net.sourceforge.plantuml.ugraphic.color.HColorGradient;
+import net.sourceforge.plantuml.utils.MathUtils;
 import net.sourceforge.plantuml.version.Version;
 
 public class EpsGraphics {
 
 	public static final String END_OF_FILE = "%plantuml done";
+	protected static final long COEF = 100L;
 
 	// http://www.linuxfocus.org/Francais/May1998/article43.html
 	// http://www.tailrecursive.org/postscript/text.html
@@ -63,7 +66,7 @@ public class EpsGraphics {
 	private Color color = Color.BLACK;
 	private Color fillcolor = Color.BLACK;
 
-	private String strokeWidth = "1";
+	private String strokeWidth = format(1);
 	// private String strokeDasharray = null;
 
 	private final PostScriptCommandMacro setcolorgradient = new PostScriptCommandMacro("setcolorgradient");
@@ -95,8 +98,8 @@ public class EpsGraphics {
 				true));
 		roundrect.add(new PostScriptCommandRaw(
 				"2 index 5 index add 1 index sub 2 index 5 index add 2 index sub 2 index 0 90 arc", true));
-		roundrect.add(new PostScriptCommandRaw("dup 3 index add 2 index 5 index add 2 index sub 2 index 90 180 arc",
-				true));
+		roundrect.add(
+				new PostScriptCommandRaw("dup 3 index add 2 index 5 index add 2 index sub 2 index 90 180 arc", true));
 		roundrect.add(new PostScriptCommandRaw("pop pop pop pop pop ", true));
 	}
 
@@ -132,7 +135,7 @@ public class EpsGraphics {
 		header.append("%%EndComments\n\n");
 		header.append("gsave\n");
 		header.append("0 " + maxY + " translate\n");
-		header.append("1 -1 scale\n");
+		header.append(".01 -.01 scale\n");
 
 		if (setcolorgradientUsed) {
 			header.append(setcolorgradient.getPostStringDefinition());
@@ -182,30 +185,42 @@ public class EpsGraphics {
 		this.fillcolor = c;
 	}
 
-	public final void setStrokeWidth(String strokeWidth, double dashVisible, double dashSpace) {
+	public final void setStrokeWidth(double strokeWidth, double dashVisible, double dashSpace) {
 		checkCloseDone();
-		this.strokeWidth = strokeWidth;
-		this.dashVisible = dashVisible;
-		this.dashSpace = dashSpace;
+		this.strokeWidth = format(strokeWidth);
+		this.dashVisible = (long) (dashVisible * COEF);
+		this.dashSpace = (long) (dashSpace * COEF);
 	}
 
-	private double dashVisible = 0;
-	private double dashSpace = 0;
+	private long dashVisible = 0;
+	private long dashSpace = 0;
 
 	public void newpathDot() {
-		final boolean dashed = dashVisible != 0 || dashSpace != 0;
+		final boolean dashed = isDashed();
 		checkCloseDone();
 		append(strokeWidth + " setlinewidth", true);
 		appendColor(color);
 
 		if (dashed) {
-			append("[9 9] 0 setdash", true);
+			append("[" + dashSpace + " " + dashVisible + "] 0 setdash", true);
 		}
 		append("newpath", true);
 	}
 
+	private boolean isDashed() {
+		return dashVisible != 0 || dashSpace != 0;
+	}
+
+	private boolean isDashed2() {
+		return dashVisible == 0 || dashSpace == 0;
+	}
+
+	private boolean isDashed3() {
+		return dashSpace != 0 && dashVisible != 0;
+	}
+
 	public void closepathDot() {
-		final boolean dashed = dashVisible != 0 || dashSpace != 0;
+		final boolean dashed = isDashed();
 		append("stroke", true);
 		if (dashed) {
 			append("[] 0 setdash", true);
@@ -219,7 +234,7 @@ public class EpsGraphics {
 		append(strokeWidth + " setlinewidth", true);
 		appendColor(color);
 		append("newpath", true);
-		if (dashVisible == 0 || dashSpace == 0) {
+		if (isDashed2()) {
 			append(format(x1) + " " + format(y1) + " moveto", true);
 			append(format(x2 - x1) + " " + format(y2 - y1) + " rlineto", true);
 		} else if (x1 == x2) {
@@ -231,31 +246,31 @@ public class EpsGraphics {
 		ensureVisible(Math.max(x1, x2), Math.max(y1, y2));
 	}
 
-	protected void epsHLine(double x, double ymin, double ymax) {
+	protected void epsHLine(final double x, final double ymin, final double ymax) {
 		append(format(x) + " " + format(ymin) + " moveto", true);
-		for (double y = ymin; y < ymax; y += dashVisible + dashSpace) {
-			final double v;
-			if (y + dashVisible > ymax) {
-				v = y - ymax;
+		for (long y2 = (long) (ymin * COEF); y2 < (long) (ymax * COEF); y2 += (dashVisible + dashSpace)) {
+			final long v;
+			if (y2 + dashVisible > (long) (ymax * COEF)) {
+				v = y2 - (long) (ymax * COEF);
 			} else {
 				v = dashSpace;
 			}
-			append("0 " + format(v) + " rlineto", true);
-			append("0 " + format(dashSpace) + " rmoveto", true);
+			append("0 " + v + " rlineto", true);
+			append("0 " + dashSpace + " rmoveto", true);
 		}
 	}
 
-	protected void epsVLine(double y, double xmin, double xmax) {
+	protected void epsVLine(final double y, final double xmin, final double xmax) {
 		append(format(xmin) + " " + format(y) + " moveto", true);
-		for (double x = xmin; x < xmax; x += dashVisible + dashSpace) {
-			final double v;
-			if (x + dashVisible > xmax) {
-				v = x - xmax;
+		for (long x2 = (long) (xmin * COEF); x2 < (long) (xmax * COEF); x2 += (dashVisible + dashSpace)) {
+			final long v;
+			if (x2 + dashVisible > (long) (xmax * COEF)) {
+				v = x2 - (long) (xmax * COEF);
 			} else {
 				v = dashSpace;
 			}
-			append(format(v) + " 0 rlineto", true);
-			append(format(dashSpace) + " 0 rmoveto", true);
+			append("" + v + " 0 rlineto", true);
+			append("" + dashSpace + " 0 rmoveto", true);
 		}
 	}
 
@@ -277,8 +292,10 @@ public class EpsGraphics {
 					curvetoNoMacro(coord[0] + x, coord[1] + y, coord[2] + x, coord[3] + y, coord[4] + x, coord[5] + y);
 				} else if (type == USegmentType.SEG_CLOSE) {
 					// Nothing
+				} else if (type == USegmentType.SEG_ARCTO) {
+					// Nothing
 				} else {
-					Log.println("unknown " + seg);
+					Log.println("unknown1 " + seg);
 				}
 			}
 			append("closepath eofill", true);
@@ -301,8 +318,10 @@ public class EpsGraphics {
 					curvetoNoMacro(coord[0] + x, coord[1] + y, coord[2] + x, coord[3] + y, coord[4] + x, coord[5] + y);
 				} else if (type == USegmentType.SEG_CLOSE) {
 					// Nothing
+				} else if (type == USegmentType.SEG_ARCTO) {
+					// Nothing
 				} else {
-					Log.println("unknown " + seg);
+					Log.println("unknown2 " + seg);
 				}
 			}
 			append("stroke", true);
@@ -310,12 +329,14 @@ public class EpsGraphics {
 
 	}
 
-	public void epsPolygon(HtmlColorGradient gr, ColorMapper mapper, double... points) {
-		setFillColor(mapper.getMappedColor(gr.getColor1()));
+	public void epsPolygon(HColorGradient gr, ColorMapper mapper, double... points) {
+		assert points.length % 2 == 0;
+		setFillColor(mapper.toColor(gr.getColor1()));
 		epsPolygon(points);
 	}
 
 	public void epsPolygon(double... points) {
+		assert points.length % 2 == 0;
 		checkCloseDone();
 		double lastX = 0;
 		double lastY = 0;
@@ -364,6 +385,10 @@ public class EpsGraphics {
 			appendColor(fillcolor);
 			epsRectangleInternal(x, y, width, height, rx, ry, true);
 			append("closepath eofill", true);
+			if (isDashed3()) {
+				append("[] 0 setdash", true);
+			}
+
 		}
 
 		if (color != null) {
@@ -371,11 +396,14 @@ public class EpsGraphics {
 			appendColor(color);
 			epsRectangleInternal(x, y, width, height, rx, ry, false);
 			append("closepath stroke", true);
+			if (isDashed3()) {
+				append("[] 0 setdash", true);
+			}
 		}
 	}
 
-	public void epsRectangle(double x, double y, double width, double height, double rx, double ry,
-			HtmlColorGradient gr, ColorMapper mapper) {
+	public void epsRectangle(double x, double y, double width, double height, double rx, double ry, HColorGradient gr,
+			ColorMapper mapper) {
 		checkCloseDone();
 		ensureVisible(x, y);
 		ensureVisible(x + width, y + height);
@@ -383,8 +411,8 @@ public class EpsGraphics {
 
 		if (rx == 0 && ry == 0) {
 			simplerectUsed = true;
-			appendColorShort(mapper.getMappedColor(gr.getColor1()));
-			appendColorShort(mapper.getMappedColor(gr.getColor2()));
+			appendColorShort(mapper.toColor(gr.getColor1()));
+			appendColorShort(mapper.toColor(gr.getColor2()));
 			append(format(width) + " " + format(height) + " " + format(x) + " " + format(y), true);
 			append("100 -1 1 {", true);
 			append("100 div", true);
@@ -406,8 +434,8 @@ public class EpsGraphics {
 			append("initclip", true);
 		} else {
 			roundrectUsed = true;
-			appendColorShort(mapper.getMappedColor(gr.getColor1()));
-			appendColorShort(mapper.getMappedColor(gr.getColor2()));
+			appendColorShort(mapper.toColor(gr.getColor1()));
+			appendColorShort(mapper.toColor(gr.getColor2()));
 			append(format(width) + " " + format(height) + " " + format(x) + " " + format(y) + " "
 					+ format((rx + ry) / 2), true);
 			append("100 -1 1 {", true);
@@ -441,21 +469,34 @@ public class EpsGraphics {
 	}
 
 	private void roundRectangle(double x, double y, double width, double height, double rx, double ry) {
-		append(format(width) + " " + format(height) + " " + format(x) + " " + format(y) + " " + format((rx + ry) / 2)
+		if (isDashed3()) {
+			append("[" + dashSpace + " " + dashVisible + "] 0 setdash", true);
+		}
+		final double round = MathUtils.min((rx + ry) / 2, width / 2, height / 2);
+		append(format(width) + " " + format(height) + " " + format(x) + " " + format(y) + " " + format(round)
 				+ " roundrect", true);
 		roundrectUsed = true;
 	}
 
 	private void simpleRectangle(double x, double y, double width, double height, boolean fill) {
-		if ((dashSpace == 0 && dashVisible == 0) || fill) {
-			append(format(width) + " " + format(height) + " " + format(x) + " " + format(y) + " simplerect", true);
-			simplerectUsed = true;
-		} else {
-			epsVLine(y, x, x + width);
-			epsVLine(y + height, x, x + width);
-			epsHLine(x, y, y + height);
-			epsHLine(x + width, y, y + height);
+		if (isDashed3()) {
+			append("[" + dashSpace + " " + dashVisible + "] 0 setdash", true);
 		}
+		// if (isDashed3() || fill) {
+		append(format(width) + " " + format(height) + " " + format(x) + " " + format(y) + " simplerect", true);
+		simplerectUsed = true;
+		// }
+	}
+
+	/**
+	 * Converts a counter clockwise angle to a clockwise angle. i.e. 0 -> 360, 90 ->
+	 * 270, 180 -> 180, 270 -> 90
+	 * 
+	 * @param counterClockwise counter clockwise angle in degrees
+	 * @return clockwise angle in degrees
+	 */
+	private int convertToClockwiseAngle(double counterClockwise) {
+		return (int) (360.0 - counterClockwise);
 	}
 
 	public void epsEllipse(double x, double y, double xRadius, double yRadius, double start, double extend) {
@@ -470,7 +511,8 @@ public class EpsGraphics {
 		// if (fillcolor != null) {
 		// appendColor(fillcolor);
 		// append("newpath", true);
-		// append(format(x) + " " + format(y / scale) + " " + format(xRadius) + " 0 360 arc", true);
+		// append(format(x) + " " + format(y / scale) + " " + format(xRadius) + " 0 360
+		// arc", true);
 		// append("closepath eofill", true);
 		// }
 
@@ -478,10 +520,10 @@ public class EpsGraphics {
 			append(strokeWidth + " setlinewidth", true);
 			appendColor(color);
 			append("newpath", true);
-			final double a1 = -start + 180 + 5;
-			final double a2 = -start - extend + 180 - 5;
-			append(format(x) + " " + format(y / scale) + " " + format(xRadius) + " " + format(a1) + " " + format(a2)
-					+ " arc", true);
+
+			final double a1 = convertToClockwiseAngle(start + extend);
+			final double a2 = convertToClockwiseAngle(start);
+			append(format(x) + " " + format(y / scale) + " " + format(xRadius) + " " + a1 + " " + a2 + " arc", true);
 			append("stroke", true);
 		}
 
@@ -497,7 +539,7 @@ public class EpsGraphics {
 		if (xRadius != yRadius) {
 			scale = yRadius / xRadius;
 			append("gsave", true);
-			append("1 " + format(scale) + " scale", true);
+			append("1 " + formatSimple4(scale) + " scale", true);
 		}
 		if (fillcolor != null) {
 			appendColor(fillcolor);
@@ -526,7 +568,7 @@ public class EpsGraphics {
 		final double r = c.getRed() / 255.0;
 		final double g = c.getGreen() / 255.0;
 		final double b = c.getBlue() / 255.0;
-		append(format(r) + " " + format(g) + " " + format(b) + " setrgbcolor", true);
+		append(formatSimple2(r) + " " + formatSimple2(g) + " " + formatSimple2(b) + " setrgbcolor", true);
 	}
 
 	protected void appendColorShort(Color c) {
@@ -536,10 +578,17 @@ public class EpsGraphics {
 		final double r = c.getRed() / 255.0;
 		final double g = c.getGreen() / 255.0;
 		final double b = c.getBlue() / 255.0;
-		append(format(r) + " " + format(g) + " " + format(b), true);
+		append(formatSimple2(r) + " " + formatSimple2(g) + " " + formatSimple2(b), true);
 	}
 
-	public static String format(double x) {
+	static String format(double x) {
+		if (x == 0) {
+			return "0";
+		}
+		return Long.toString((long) (x * COEF));
+	}
+
+	public static String formatSimple4(double x) {
 		if (x == 0) {
 			return "0";
 		}
@@ -551,6 +600,18 @@ public class EpsGraphics {
 		return s;
 	}
 
+	private static String formatSimple2(double x) {
+		if (x == 0) {
+			return "0";
+		}
+		String s = String.format(Locale.US, "%1.2f", x);
+		s = s.replaceAll("(\\.\\d*?)0+$", "$1");
+		if (s.endsWith(".")) {
+			s = s.substring(0, s.length() - 1);
+		}
+		return s;
+	}
+
 	protected void append(String s, boolean checkConsistence) {
 		if (checkConsistence && s.indexOf("  ") != -1) {
 			throw new IllegalArgumentException(s);
@@ -569,8 +630,8 @@ public class EpsGraphics {
 	}
 
 	final public void curvetoNoMacro(double x1, double y1, double x2, double y2, double x3, double y3) {
-		append(format(x1) + " " + format(y1) + " " + format(x2) + " " + format(y2) + " " + format(x3) + " "
-				+ format(y3) + " curveto", true);
+		append(format(x1) + " " + format(y1) + " " + format(x2) + " " + format(y2) + " " + format(x3) + " " + format(y3)
+				+ " curveto", true);
 		ensureVisible(x1, y1);
 		ensureVisible(x2, y2);
 		ensureVisible(x3, y3);
@@ -588,16 +649,16 @@ public class EpsGraphics {
 	}
 
 	public void curveto(double x1, double y1, double x2, double y2, double x3, double y3) {
-		append(format(x1) + " " + format(y1) + " " + format(x2) + " " + format(y2) + " " + format(x3) + " "
-				+ format(y3) + " curveto", true);
+		append(format(x1) + " " + format(y1) + " " + format(x2) + " " + format(y2) + " " + format(x3) + " " + format(y3)
+				+ " curveto", true);
 		ensureVisible(x1, y1);
 		ensureVisible(x2, y2);
 		ensureVisible(x3, y3);
 	}
 
 	public void quadto(double x1, double y1, double x2, double y2) {
-		append(format(x1) + " " + format(y1) + " " + format(x1) + " " + format(y1) + " " + format(x2) + " "
-				+ format(y2) + " curveto", true);
+		append(format(x1) + " " + format(y1) + " " + format(x1) + " " + format(y1) + " " + format(x2) + " " + format(y2)
+				+ " curveto", true);
 		ensureVisible(x1, y1);
 		ensureVisible(x2, y2);
 	}
@@ -674,11 +735,11 @@ public class EpsGraphics {
 		append("grestore", true);
 	}
 
-	protected final double getDashVisible() {
+	protected final long getDashVisible() {
 		return dashVisible;
 	}
 
-	protected final double getDashSpace() {
+	protected final long getDashSpace() {
 		return dashSpace;
 	}
 
@@ -730,6 +791,10 @@ public class EpsGraphics {
 	}
 
 	public void openLink(String url) {
+		// javascript: security issue
+		if (SecurityUtils.ignoreThisLink(url))
+			return;
+
 		this.urlArea = new UrlArea(url);
 	}
 
@@ -748,6 +813,7 @@ public class EpsGraphics {
 	}
 
 	public void epsPolygonShadow(double deltaShadow, double... points) {
+		assert points.length % 2 == 0;
 		setStrokeColor(null);
 		for (double i = 0; i <= deltaShadow; i += 0.5) {
 			setFillColor(shadowManager.getColor(i, deltaShadow));
