@@ -2,7 +2,7 @@
  * PlantUML : a free UML diagram generator
  * ========================================================================
  *
- * (C) Copyright 2009-2017, Arnaud Roques
+ * (C) Copyright 2009-2020, Arnaud Roques
  *
  * Project Info:  http://plantuml.com
  * 
@@ -38,12 +38,15 @@ package net.sourceforge.plantuml.graphic;
 import java.awt.geom.Dimension2D;
 
 import net.sourceforge.plantuml.Dimension2DDouble;
+import net.sourceforge.plantuml.UseStyle;
+import net.sourceforge.plantuml.style.SName;
 import net.sourceforge.plantuml.ugraphic.AbstractUGraphicHorizontalLine;
-import net.sourceforge.plantuml.ugraphic.UChangeBackColor;
+import net.sourceforge.plantuml.ugraphic.UEmpty;
 import net.sourceforge.plantuml.ugraphic.UGraphic;
 import net.sourceforge.plantuml.ugraphic.UHorizontalLine;
 import net.sourceforge.plantuml.ugraphic.UPath;
 import net.sourceforge.plantuml.ugraphic.UTranslate;
+import net.sourceforge.plantuml.ugraphic.color.HColorNone;
 
 class USymbolDatabase extends USymbol {
 
@@ -51,14 +54,17 @@ class USymbolDatabase extends USymbol {
 	public SkinParameter getSkinParameter() {
 		return SkinParameter.DATABASE;
 	}
+	
+	@Override
+	public SName getSName() {
+		return SName.database;
+	}
 
 
-
-	private void drawDatabase(UGraphic ug, double width, double height, boolean shadowing) {
+	private void drawDatabase(UGraphic ug, double width, double height, double shadowing) {
 		final UPath shape = new UPath();
-		if (shadowing) {
-			shape.setDeltaShadow(3.0);
-		}
+		shape.setDeltaShadow(shadowing);
+
 		shape.moveTo(0, 10);
 		shape.cubicTo(0, 0, width / 2, 0, width / 2, 0);
 		shape.cubicTo(width / 2, 0, width, 0, width, 10);
@@ -70,7 +76,13 @@ class USymbolDatabase extends USymbol {
 		ug.draw(shape);
 
 		final UPath closing = getClosingPath(width);
-		ug.apply(new UChangeBackColor(null)).draw(closing);
+		ug.apply(new HColorNone().bg()).draw(closing);
+
+		if (UseStyle.useBetaStyle()) {
+			ug.apply(new UTranslate(width, height)).draw(new UEmpty(10, 10));
+			// ug.apply(HColorUtils.BLACK).apply(new UTranslate(width, height)).draw(new
+			// URectangle(10, 10));
+		}
 
 	}
 
@@ -100,10 +112,9 @@ class USymbolDatabase extends USymbol {
 		protected void drawHline(UGraphic ug, UHorizontalLine line, UTranslate translate) {
 			final UPath closing = getClosingPath(endingX);
 			ug = ug.apply(translate);
-			ug.apply(line.getStroke()).apply(new UChangeBackColor(null)).apply(new UTranslate(0, -15)).draw(closing);
+			ug.apply(line.getStroke()).apply(new HColorNone().bg()).apply(UTranslate.dy(-15)).draw(closing);
 			if (line.isDouble()) {
-				ug.apply(line.getStroke()).apply(new UChangeBackColor(null)).apply(new UTranslate(0, -15 + 2))
-						.draw(closing);
+				ug.apply(line.getStroke()).apply(new HColorNone().bg()).apply(UTranslate.dy(-15 + 2)).draw(closing);
 			}
 			line.drawTitleInternal(ug, 0, endingX, 0, true);
 		}
@@ -114,13 +125,15 @@ class USymbolDatabase extends USymbol {
 		return new Margin(10, 10, 24, 5);
 	}
 
-	public TextBlock asSmall(TextBlock name, final TextBlock label, final TextBlock stereotype, final SymbolContext symbolContext) {
+	@Override
+	public TextBlock asSmall(TextBlock name, final TextBlock label, final TextBlock stereotype,
+			final SymbolContext symbolContext, final HorizontalAlignment stereoAlignment) {
 		return new AbstractTextBlock() {
 
 			public void drawU(UGraphic ug) {
 				final Dimension2D dim = calculateDimension(ug.getStringBounder());
 				ug = symbolContext.apply(ug);
-				drawDatabase(ug, dim.getWidth(), dim.getHeight(), symbolContext.isShadowing());
+				drawDatabase(ug, dim.getWidth(), dim.getHeight(), symbolContext.getDeltaShadow());
 				final Margin margin = getMargin();
 				final TextBlock tb = TextBlockUtils.mergeTB(stereotype, label, HorizontalAlignment.CENTER);
 				final UGraphic ug2 = new MyUGraphicDatabase(ug, dim.getWidth());
@@ -135,21 +148,23 @@ class USymbolDatabase extends USymbol {
 		};
 	}
 
-	public TextBlock asBig(final TextBlock title, final TextBlock stereotype, final double width, final double height,
-			final SymbolContext symbolContext) {
+	@Override
+	public TextBlock asBig(final TextBlock title, HorizontalAlignment labelAlignment, final TextBlock stereotype,
+			final double width, final double height, final SymbolContext symbolContext,
+			final HorizontalAlignment stereoAlignment) {
 		return new AbstractTextBlock() {
 
 			public void drawU(UGraphic ug) {
 				final Dimension2D dim = calculateDimension(ug.getStringBounder());
 				ug = symbolContext.apply(ug);
-				drawDatabase(ug, dim.getWidth(), dim.getHeight(), symbolContext.isShadowing());
+				drawDatabase(ug, dim.getWidth(), dim.getHeight(), symbolContext.getDeltaShadow());
 				final Dimension2D dimStereo = stereotype.calculateDimension(ug.getStringBounder());
 				final double posStereo = (width - dimStereo.getWidth()) / 2;
-				stereotype.drawU(ug.apply(new UTranslate(posStereo, 0)));
+				stereotype.drawU(ug.apply(new UTranslate(posStereo, 2 + 20)));
 
 				final Dimension2D dimTitle = title.calculateDimension(ug.getStringBounder());
 				final double posTitle = (width - dimTitle.getWidth()) / 2;
-				title.drawU(ug.apply(new UTranslate(posTitle, 21)));
+				title.drawU(ug.apply(new UTranslate(posTitle, 2 + 20 + dimStereo.getHeight())));
 			}
 
 			public Dimension2D calculateDimension(StringBounder stringBounder) {
@@ -158,10 +173,6 @@ class USymbolDatabase extends USymbol {
 		};
 	}
 
-	public boolean manageHorizontalLine() {
-		return true;
-	}
-
 	@Override
 	public int suppHeightBecauseOfShape() {
 		return 15;
