@@ -2,7 +2,7 @@
  * PlantUML : a free UML diagram generator
  * ========================================================================
  *
- * (C) Copyright 2009-2017, Arnaud Roques
+ * (C) Copyright 2009-2020, Arnaud Roques
  *
  * Project Info:  http://plantuml.com
  * 
@@ -38,22 +38,42 @@ package net.sourceforge.plantuml.graphic;
 import java.awt.geom.Dimension2D;
 
 import net.sourceforge.plantuml.Dimension2DDouble;
+import net.sourceforge.plantuml.UseStyle;
+import net.sourceforge.plantuml.style.SName;
 import net.sourceforge.plantuml.ugraphic.AbstractUGraphicHorizontalLine;
-import net.sourceforge.plantuml.ugraphic.UChangeBackColor;
+import net.sourceforge.plantuml.ugraphic.UEmpty;
 import net.sourceforge.plantuml.ugraphic.UGraphic;
 import net.sourceforge.plantuml.ugraphic.UHorizontalLine;
 import net.sourceforge.plantuml.ugraphic.ULine;
 import net.sourceforge.plantuml.ugraphic.UPolygon;
 import net.sourceforge.plantuml.ugraphic.UTranslate;
+import net.sourceforge.plantuml.ugraphic.color.HColorNone;
 
 class USymbolNode extends USymbol {
 
+	// private final HorizontalAlignment stereotypeAlignement;
+
 	@Override
 	public SkinParameter getSkinParameter() {
 		return SkinParameter.NODE;
 	}
+	
+	@Override
+	public SName getSName() {
+		return SName.node;
+	}
 
-	private void drawNode(UGraphic ug, double width, double height, boolean shadowing) {
+
+//	public USymbolNode(HorizontalAlignment stereotypeAlignement) {
+//		this.stereotypeAlignement = stereotypeAlignement;
+//	}
+//
+//	@Override
+//	public USymbol withStereoAlignment(HorizontalAlignment alignment) {
+//		return new USymbolNode(alignment);
+//	}
+
+	private void drawNode(UGraphic ug, double width, double height, double shadowing) {
 		final UPolygon shape = new UPolygon();
 		shape.addPoint(0, 10);
 		shape.addPoint(10, 0);
@@ -62,14 +82,18 @@ class USymbolNode extends USymbol {
 		shape.addPoint(width - 10, height);
 		shape.addPoint(0, height);
 		shape.addPoint(0, 10);
-		if (shadowing) {
-			shape.setDeltaShadow(2);
-		}
+
+		shape.setDeltaShadow(shadowing);
+
 		ug.draw(shape);
 
-		ug.apply(new UTranslate(width - 10, 10)).draw(new ULine(9, -9));
-		ug.apply(new UTranslate(0, 10)).draw(new ULine(width - 10, 0));
-		ug.apply(new UTranslate(width - 10, 10)).draw(new ULine(0, height - 10));
+		ug.apply(new UTranslate(width - 10, 10)).draw(new ULine(10, -10));
+
+		ug.apply(UTranslate.dy(10)).draw(ULine.hline(width - 10));
+		ug.apply(new UTranslate(width - 10, 10)).draw(ULine.vline(height - 10));
+		if (UseStyle.useBetaStyle()) {
+			ug.apply(new UTranslate(0, height)).draw(new UEmpty(10, 10));
+		}
 
 	}
 
@@ -93,15 +117,15 @@ class USymbolNode extends USymbol {
 
 			drawHlineInternal(ug, line);
 			if (line.isDouble()) {
-				drawHlineInternal(ug.apply(new UTranslate(0, 2)), line);
+				drawHlineInternal(ug.apply(UTranslate.dy(2)), line);
 			}
 			line.drawTitleInternal(ug, 0, endingX - 10, 0, true);
 		}
 
 		private void drawHlineInternal(UGraphic ug, UHorizontalLine line) {
-			ug = ug.apply(line.getStroke()).apply(new UChangeBackColor(null));
-			ug.draw(new ULine(endingX - 10, 0));
-			ug.apply(new UTranslate(endingX - 10, 0)).draw(new ULine(10, -10));
+			ug = ug.apply(line.getStroke()).apply(new HColorNone().bg());
+			ug.draw(ULine.hline(endingX - 10));
+			ug.apply(UTranslate.dx(endingX - 10)).draw(new ULine(10, -10));
 		}
 	}
 
@@ -109,16 +133,17 @@ class USymbolNode extends USymbol {
 		return new Margin(10 + 5, 20 + 5, 15 + 5, 5 + 5);
 	}
 
+	@Override
 	public TextBlock asSmall(TextBlock name, final TextBlock label, final TextBlock stereotype,
-			final SymbolContext symbolContext) {
+			final SymbolContext symbolContext, final HorizontalAlignment stereoAlignment) {
 		return new AbstractTextBlock() {
 
 			public void drawU(UGraphic ug) {
 				final Dimension2D dim = calculateDimension(ug.getStringBounder());
 				ug = symbolContext.apply(ug);
-				drawNode(ug, dim.getWidth(), dim.getHeight(), symbolContext.isShadowing());
+				drawNode(ug, dim.getWidth(), dim.getHeight(), symbolContext.getDeltaShadow());
 				final Margin margin = getMargin();
-				final TextBlock tb = TextBlockUtils.mergeTB(stereotype, label, HorizontalAlignment.CENTER);
+				final TextBlock tb = TextBlockUtils.mergeTB(stereotype, label, stereoAlignment);
 				final UGraphic ug2 = new MyUGraphicNode(ug, dim.getWidth());
 				tb.drawU(ug2.apply(new UTranslate(margin.getX1(), margin.getY1())));
 			}
@@ -131,19 +156,28 @@ class USymbolNode extends USymbol {
 		};
 	}
 
-	public TextBlock asBig(final TextBlock title, final TextBlock stereotype, final double width, final double height,
-			final SymbolContext symbolContext) {
+	@Override
+	public TextBlock asBig(final TextBlock title, HorizontalAlignment labelAlignment, final TextBlock stereotype,
+			final double width, final double height, final SymbolContext symbolContext,
+			final HorizontalAlignment stereoAlignment) {
 		return new AbstractTextBlock() {
 
 			public void drawU(UGraphic ug) {
 				final Dimension2D dim = calculateDimension(ug.getStringBounder());
 				ug = symbolContext.apply(ug);
-				drawNode(ug, dim.getWidth(), dim.getHeight(), symbolContext.isShadowing());
+				drawNode(ug, dim.getWidth(), dim.getHeight(), symbolContext.getDeltaShadow());
 				ug = ug.apply(new UTranslate(-4, 11));
 
 				final Dimension2D dimStereo = stereotype.calculateDimension(ug.getStringBounder());
-				final double posStereo = (width - dimStereo.getWidth()) / 2;
-				stereotype.drawU(ug.apply(new UTranslate(posStereo, 2)));
+				final double posStereoX;
+				final double posStereoY = 2;
+				if (stereoAlignment == HorizontalAlignment.RIGHT) {
+					posStereoX = width - dimStereo.getWidth() - getMargin().getX1();
+				} else {
+					posStereoX = (width - dimStereo.getWidth()) / 2;
+
+				}
+				stereotype.drawU(ug.apply(new UTranslate(posStereoX, posStereoY)));
 				final Dimension2D dimTitle = title.calculateDimension(ug.getStringBounder());
 				final double posTitle = (width - dimTitle.getWidth()) / 2;
 				title.drawU(ug.apply(new UTranslate(posTitle, 2 + dimStereo.getHeight())));
@@ -156,10 +190,6 @@ class USymbolNode extends USymbol {
 		};
 	}
 
-	public boolean manageHorizontalLine() {
-		return true;
-	}
-
 	@Override
 	public int suppHeightBecauseOfShape() {
 		return 5;
