@@ -39,6 +39,7 @@ import java.awt.geom.Dimension2D;
 import java.awt.geom.Point2D;
 
 import net.sourceforge.plantuml.Dimension2DDouble;
+import net.sourceforge.plantuml.style.SName;
 import net.sourceforge.plantuml.ugraphic.UGraphic;
 import net.sourceforge.plantuml.ugraphic.UGraphicStencil;
 import net.sourceforge.plantuml.ugraphic.UPath;
@@ -52,8 +53,14 @@ class USymbolStack extends USymbol {
 	public SkinParameter getSkinParameter() {
 		return SkinParameter.STACK;
 	}
+	
+	@Override
+	public SName getSName() {
+		return SName.stack;
+	}
 
-	private void drawQueue(UGraphic ug, double width, double height, boolean shadowing, double roundCorner) {
+
+	private void drawQueue(UGraphic ug, double width, double height, double shadowing, double roundCorner) {
 		final double border = 15;
 
 		final URectangle rect = new URectangle(width - 2 * border, height).rounded(roundCorner);
@@ -79,9 +86,7 @@ class USymbolStack extends USymbol {
 			path.arcTo(new Point2D.Double(width - border + roundCorner / 2, 0), roundCorner / 2, 0, 1);
 			path.lineTo(width, 0);
 		}
-		if (shadowing) {
-			path.setDeltaShadow(3.0);
-		}
+		path.setDeltaShadow(shadowing);
 		ug.apply(new HColorNone().bg()).draw(path);
 	}
 
@@ -98,7 +103,7 @@ class USymbolStack extends USymbol {
 				final Dimension2D dim = calculateDimension(ug.getStringBounder());
 				ug = UGraphicStencil.create(ug, dim);
 				ug = symbolContext.apply(ug);
-				drawQueue(ug, dim.getWidth(), dim.getHeight(), symbolContext.isShadowing(),
+				drawQueue(ug, dim.getWidth(), dim.getHeight(), symbolContext.getDeltaShadow(),
 						symbolContext.getRoundCorner());
 				final Margin margin = getMargin();
 				final TextBlock tb = TextBlockUtils.mergeTB(stereotype, label, HorizontalAlignment.CENTER);
@@ -122,7 +127,7 @@ class USymbolStack extends USymbol {
 			public void drawU(UGraphic ug) {
 				final Dimension2D dim = calculateDimension(ug.getStringBounder());
 				ug = symbolContext.apply(ug);
-				drawQueue(ug, dim.getWidth(), dim.getHeight(), symbolContext.isShadowing(),
+				drawQueue(ug, dim.getWidth(), dim.getHeight(), symbolContext.getDeltaShadow(),
 						symbolContext.getRoundCorner());
 				final Dimension2D dimStereo = stereotype.calculateDimension(ug.getStringBounder());
 				final double posStereo = (width - dimStereo.getWidth()) / 2;
