@@ -42,6 +42,7 @@ import net.sourceforge.plantuml.ISkinSimple;
 import net.sourceforge.plantuml.command.Command;
 import net.sourceforge.plantuml.command.CommandFootboxIgnored;
 import net.sourceforge.plantuml.command.PSystemCommandFactory;
+import net.sourceforge.plantuml.command.CommonCommands;
 import net.sourceforge.plantuml.core.DiagramType;
 import net.sourceforge.plantuml.core.UmlSource;
 
@@ -60,7 +61,7 @@ public class NwDiagramFactory extends PSystemCommandFactory {
 	protected List<Command> createCommands() {
 
 		final List<Command> cmds = new ArrayList<>();
-		addCommonCommands1(cmds);
+		CommonCommands.addCommonCommands1(cmds);
 		cmds.add(new CommandNwDiagInit());
 		cmds.add(new CommandComment());
 		cmds.add(new CommandElement());
