@@ -150,7 +150,7 @@ public class PSystemSalt extends TitledDiagram implements WithSprite {
 			}
 
 			public HColor getBackcolor() {
-				return getSkinParam().getBackgroundColor(false);
+				return getSkinParam().getBackgroundColor();
 			}
 		};
 	}
