@@ -2,7 +2,7 @@
  * PlantUML : a free UML diagram generator
  * ========================================================================
  *
- * (C) Copyright 2009-2017, Arnaud Roques
+ * (C) Copyright 2009-2020, Arnaud Roques
  *
  * Project Info:  http://plantuml.com
  * 
@@ -38,41 +38,50 @@ package net.sourceforge.plantuml.sequencediagram.teoz;
 import java.awt.geom.Dimension2D;
 
 import net.sourceforge.plantuml.ISkinParam;
+import net.sourceforge.plantuml.LineParam;
+import net.sourceforge.plantuml.cucadiagram.Display;
 import net.sourceforge.plantuml.graphic.HorizontalAlignment;
 import net.sourceforge.plantuml.graphic.StringBounder;
 import net.sourceforge.plantuml.graphic.VerticalAlignment;
 import net.sourceforge.plantuml.real.Real;
 import net.sourceforge.plantuml.sequencediagram.Event;
 import net.sourceforge.plantuml.sequencediagram.Message;
+import net.sourceforge.plantuml.sequencediagram.Participant;
 import net.sourceforge.plantuml.skin.Area;
 import net.sourceforge.plantuml.skin.ArrowComponent;
 import net.sourceforge.plantuml.skin.ArrowConfiguration;
 import net.sourceforge.plantuml.skin.Component;
-import net.sourceforge.plantuml.skin.ComponentType;
 import net.sourceforge.plantuml.skin.Context2D;
-import net.sourceforge.plantuml.skin.Skin;
+import net.sourceforge.plantuml.skin.rose.AbstractComponentRoseArrow;
+import net.sourceforge.plantuml.skin.rose.Rose;
 import net.sourceforge.plantuml.ugraphic.UGraphic;
+import net.sourceforge.plantuml.ugraphic.UStroke;
 import net.sourceforge.plantuml.ugraphic.UTranslate;
 
-public class CommunicationTile implements TileWithUpdateStairs, TileWithCallbackY {
+public class CommunicationTile extends AbstractTile {
 
 	private final LivingSpace livingSpace1;
 	private final LivingSpace livingSpace2;
+	private final LivingSpaces livingSpaces;
 	private final Message message;
-	private final Skin skin;
+	private final Rose skin;
 	private final ISkinParam skinParam;
 
 	public Event getEvent() {
 		return message;
 	}
 
-	public CommunicationTile(LivingSpace livingSpace1, LivingSpace livingSpace2, Message message, Skin skin,
+	@Override
+	public String toString() {
+		return super.toString() + " " + message;
+	}
+
+	public CommunicationTile(StringBounder stringBounder, LivingSpaces livingSpaces, Message message, Rose skin,
 			ISkinParam skinParam) {
-		if (livingSpace1 == livingSpace2) {
-			throw new IllegalArgumentException();
-		}
-		this.livingSpace1 = livingSpace1;
-		this.livingSpace2 = livingSpace2;
+		super(stringBounder);
+		this.livingSpace1 = livingSpaces.get(message.getParticipant1());
+		this.livingSpace2 = livingSpaces.get(message.getParticipant2());
+		this.livingSpaces = livingSpaces;
 		this.message = message;
 		this.skin = skin;
 		this.skinParam = skinParam;
@@ -80,11 +89,6 @@ public class CommunicationTile implements TileWithUpdateStairs, TileWithCallback
 		if (message.isCreate()) {
 			livingSpace2.goCreate();
 		}
-		// for (LifeEvent lifeEvent : message.getLiveEvents()) {
-		// System.err.println("lifeEvent = " + lifeEvent);
-		// // livingSpace1.addLifeEvent(this, lifeEvent);
-		// // livingSpace2.addLifeEvent(this, lifeEvent);
-		// }
 	}
 
 	public boolean isReverse(StringBounder stringBounder) {
@@ -100,40 +104,69 @@ public class CommunicationTile implements TileWithUpdateStairs, TileWithCallback
 		return message.isCreate();
 	}
 
-	private Component getComponent(StringBounder stringBounder) {
+	private double getArrowThickness() {
+		final UStroke result = skinParam.getThickness(LineParam.sequenceArrow, null);
+		if (result == null) {
+			return 1;
+		}
+		return result.getThickness();
+	}
+
+	private ArrowComponent getComponent(StringBounder stringBounder) {
 		ArrowConfiguration arrowConfiguration = message.getArrowConfiguration();
-		/*
-		 * if (isSelf()) { arrowConfiguration = arrowConfiguration.self(); } else
-		 */
 		if (isReverse(stringBounder)) {
 			arrowConfiguration = arrowConfiguration.reverse();
 		}
-		final Component comp = skin.createComponent(ComponentType.ARROW, arrowConfiguration, skinParam,
+		arrowConfiguration = arrowConfiguration.withThickness(getArrowThickness());
+
+		return skin.createComponentArrow(message.getUsedStyles(), arrowConfiguration, skinParam,
 				message.getLabelNumbered());
-		return comp;
+	}
+
+	private ArrowComponent getComponentMulticast(StringBounder stringBounder, boolean reverse) {
+		ArrowConfiguration arrowConfiguration = message.getArrowConfiguration();
+		if (reverse) {
+			arrowConfiguration = arrowConfiguration.reverse();
+		}
+		arrowConfiguration = arrowConfiguration.withThickness(getArrowThickness());
+
+		return skin.createComponentArrow(message.getUsedStyles(), arrowConfiguration, skinParam, Display.NULL);
+	}
+
+	@Override
+	public double getContactPointRelative() {
+		return getComponent(getStringBounder()).getYPoint(getStringBounder());
 	}
 
 	public static final double LIVE_DELTA_SIZE = 5;
 
-	public void updateStairs(StringBounder stringBounder, double y) {
-		final ArrowComponent comp = (ArrowComponent) getComponent(stringBounder);
-		final Dimension2D dim = comp.getPreferredDimension(stringBounder);
-		// final Point2D p2 = comp.getEndPoint(stringBounder, dim);
-		// System.err.println("CommunicationTile::updateStairs y=" + y + " p1=" + p1 + " p2=" + p2 + " dim=" + dim);
-		final double arrowY = comp.getStartPoint(stringBounder, dim).getY();
+	@Override
+	final protected void callbackY_internal(double y) {
+		if (message.isCreate()) {
+			livingSpace2.goCreate(y);
+		}
+
+		final AbstractComponentRoseArrow comp = (AbstractComponentRoseArrow) getComponent(getStringBounder());
+		final Dimension2D dim = comp.getPreferredDimension(getStringBounder());
+
+		final double arrowY = comp.getStartPoint(getStringBounder(), dim).getY();
 
 		livingSpace1.addStepForLivebox(getEvent(), y + arrowY);
 		livingSpace2.addStepForLivebox(getEvent(), y + arrowY);
-
-		// System.err.println("CommunicationTile::updateStairs msg=" + message + " y=" + y + " arrowY=" + arrowY);
 	}
 
 	public void drawU(UGraphic ug) {
+		final String anchor1 = message.getPart1Anchor();
+		final String anchor2 = message.getPart2Anchor();
+		if (anchor1 != null || anchor2 != null) {
+			return;
+		}
 		final StringBounder stringBounder = ug.getStringBounder();
-		final Component comp = getComponent(stringBounder);
+		final ArrowComponent comp = getComponent(stringBounder);
 		final Dimension2D dim = comp.getPreferredDimension(stringBounder);
 		double x1 = getPoint1(stringBounder).getCurrentValue();
 		double x2 = getPoint2(stringBounder).getCurrentValue();
+		drawMulticast(ug.apply(UTranslate.dy(comp.getPosArrow(stringBounder))));
 
 		final Area area;
 		if (isReverse(stringBounder)) {
@@ -144,7 +177,7 @@ public class CommunicationTile implements TileWithUpdateStairs, TileWithCallback
 			}
 			x2 += LIVE_DELTA_SIZE * level2;
 			area = new Area(x1 - x2, dim.getHeight());
-			ug = ug.apply(new UTranslate(x2, 0));
+			ug = ug.apply(UTranslate.dx(x2));
 			if (isCreate()) {
 				livingSpace2.drawHead(ug, (Context2D) ug, VerticalAlignment.TOP, HorizontalAlignment.RIGHT);
 			}
@@ -157,35 +190,54 @@ public class CommunicationTile implements TileWithUpdateStairs, TileWithCallback
 			x1 += LIVE_DELTA_SIZE * level1;
 			x2 += LIVE_DELTA_SIZE * level2;
 			area = new Area(x2 - x1, dim.getHeight());
-			ug = ug.apply(new UTranslate(x1, 0));
+			ug = ug.apply(UTranslate.dx(x1));
 			if (isCreate()) {
-				livingSpace2.drawHead(ug.apply(new UTranslate(area.getDimensionToUse().getWidth(), 0)), (Context2D) ug,
+				livingSpace2.drawHead(ug.apply(UTranslate.dx(area.getDimensionToUse().getWidth())), (Context2D) ug,
 						VerticalAlignment.TOP, HorizontalAlignment.LEFT);
 			}
 		}
 		comp.drawU(ug, area, (Context2D) ug);
-		// ug.draw(new ULine(x2 - x1, 0));
+	}
+
+	private void drawMulticast(final UGraphic ug) {
+		if (message.getMulticast().size() == 0) {
+			return;
+		}
+		final StringBounder stringBounder = ug.getStringBounder();
+
+		final double x1 = getPoint1(stringBounder).getCurrentValue();
+		double dy = 2;
+		for (Participant participant : message.getMulticast()) {
+			final double x2 = livingSpaces.get(participant).getPosC(stringBounder).getCurrentValue();
+			final boolean reverse = x2 < x1;
+			final ArrowComponent comp = getComponentMulticast(stringBounder, reverse);
+			final Dimension2D dim = comp.getPreferredDimension(stringBounder);
+			final Area area = new Area(Math.abs(x2 - x1), dim.getHeight());
+			final UGraphic ug2 = ug.apply(UTranslate.dx(Math.min(x1, x2))).apply(UTranslate.dy(dy));
+			dy += 2;
+			comp.drawU(ug2, area, (Context2D) ug2);
+		}
 
 	}
 
-	public double getPreferredHeight(StringBounder stringBounder) {
-		final Component comp = getComponent(stringBounder);
-		final Dimension2D dim = comp.getPreferredDimension(stringBounder);
+	public double getPreferredHeight() {
+		final Component comp = getComponent(getStringBounder());
+		final Dimension2D dim = comp.getPreferredDimension(getStringBounder());
 		double height = dim.getHeight();
 		if (isCreate()) {
-			height = Math.max(height, livingSpace2.getHeadPreferredDimension(stringBounder).getHeight());
+			height = Math.max(height, livingSpace2.getHeadPreferredDimension(getStringBounder()).getHeight());
 		}
 		return height;
 	}
 
-	public void addConstraints(StringBounder stringBounder) {
-		final Component comp = getComponent(stringBounder);
-		final Dimension2D dim = comp.getPreferredDimension(stringBounder);
+	public void addConstraints() {
+		final Component comp = getComponent(getStringBounder());
+		final Dimension2D dim = comp.getPreferredDimension(getStringBounder());
 		final double width = dim.getWidth();
 
-		Real point1 = getPoint1(stringBounder);
-		Real point2 = getPoint2(stringBounder);
-		if (isReverse(stringBounder)) {
+		Real point1 = getPoint1(getStringBounder());
+		Real point2 = getPoint2(getStringBounder());
+		if (isReverse(getStringBounder())) {
 			final int level1 = livingSpace1.getLevelAt(this, EventsHistoryMode.IGNORE_FUTURE_DEACTIVATE);
 			final int level2 = livingSpace2.getLevelAt(this, EventsHistoryMode.IGNORE_FUTURE_DEACTIVATE);
 			if (level1 > 0) {
@@ -211,29 +263,23 @@ public class CommunicationTile implements TileWithUpdateStairs, TileWithCallback
 			if (isReverse(stringBounder)) {
 				return livingSpace2.getPosD(stringBounder);
 			}
-			return livingSpace2.getPosB();
+			return livingSpace2.getPosB(stringBounder);
 		}
 		return livingSpace2.getPosC(stringBounder);
 	}
 
-	public Real getMinX(StringBounder stringBounder) {
-		if (isReverse(stringBounder)) {
-			return getPoint2(stringBounder);
+	public Real getMinX() {
+		if (isReverse(getStringBounder())) {
+			return getPoint2(getStringBounder());
 		}
-		return getPoint1(stringBounder);
+		return getPoint1(getStringBounder());
 	}
 
-	public Real getMaxX(StringBounder stringBounder) {
-		if (isReverse(stringBounder)) {
-			return getPoint1(stringBounder);
-		}
-		return getPoint2(stringBounder);
-	}
-
-	public void callbackY(double y) {
-		if (message.isCreate()) {
-			livingSpace2.goCreate(y);
+	public Real getMaxX() {
+		if (isReverse(getStringBounder())) {
+			return getPoint1(getStringBounder());
 		}
+		return getPoint2(getStringBounder());
 	}
 
 }
