@@ -2,7 +2,7 @@
  * PlantUML : a free UML diagram generator
  * ========================================================================
  *
- * (C) Copyright 2009-2017, Arnaud Roques
+ * (C) Copyright 2009-2020, Arnaud Roques
  *
  * Project Info:  http://plantuml.com
  * 
@@ -44,13 +44,13 @@ import net.sourceforge.plantuml.Dimension2DDouble;
 import net.sourceforge.plantuml.FileFormatOption;
 import net.sourceforge.plantuml.FontParam;
 import net.sourceforge.plantuml.ISkinParam;
+import net.sourceforge.plantuml.UseStyle;
 import net.sourceforge.plantuml.activitydiagram3.ftile.EntityImageLegend;
 import net.sourceforge.plantuml.core.ImageData;
 import net.sourceforge.plantuml.cucadiagram.Display;
 import net.sourceforge.plantuml.cucadiagram.DisplaySection;
 import net.sourceforge.plantuml.graphic.FontConfiguration;
 import net.sourceforge.plantuml.graphic.HorizontalAlignment;
-import net.sourceforge.plantuml.graphic.HtmlColor;
 import net.sourceforge.plantuml.graphic.StringBounder;
 import net.sourceforge.plantuml.graphic.TextBlock;
 import net.sourceforge.plantuml.graphic.TextBlockUtils;
@@ -64,58 +64,64 @@ import net.sourceforge.plantuml.sequencediagram.Participant;
 import net.sourceforge.plantuml.sequencediagram.SequenceDiagram;
 import net.sourceforge.plantuml.sequencediagram.graphic.FileMaker;
 import net.sourceforge.plantuml.skin.SimpleContext2D;
-import net.sourceforge.plantuml.skin.Skin;
-import net.sourceforge.plantuml.ugraphic.ImageBuilder;
+import net.sourceforge.plantuml.skin.rose.Rose;
+import net.sourceforge.plantuml.style.SName;
+import net.sourceforge.plantuml.style.Style;
+import net.sourceforge.plantuml.style.StyleSignature;
 import net.sourceforge.plantuml.ugraphic.UGraphic;
 import net.sourceforge.plantuml.ugraphic.UTranslate;
+import net.sourceforge.plantuml.ugraphic.color.HColor;
 import net.sourceforge.plantuml.utils.MathUtils;
 
 public class SequenceDiagramFileMakerTeoz implements FileMaker {
 
 	private final SequenceDiagram diagram;
 	private final FileFormatOption fileFormatOption;
-	private final Skin skin;
+	private final Rose skin;
 	private final AnnotatedWorker annotatedWorker;
+	private final int index;
 
-	public SequenceDiagramFileMakerTeoz(SequenceDiagram sequenceDiagram, Skin skin, FileFormatOption fileFormatOption) {
-		this.stringBounder = fileFormatOption.getDefaultStringBounder();
-		this.diagram = sequenceDiagram;
+	public SequenceDiagramFileMakerTeoz(SequenceDiagram diagram, Rose skin, FileFormatOption fileFormatOption,
+			int index) {
+		this.index = index;
+		this.stringBounder = fileFormatOption.getDefaultStringBounder(diagram.getSkinParam());
+		this.diagram = diagram;
 		this.fileFormatOption = fileFormatOption;
 		this.skin = skin;
+		this.body = new PlayingSpaceWithParticipants(createMainTile());
 		this.footer = getFooterOrHeader(FontParam.FOOTER);
 		this.header = getFooterOrHeader(FontParam.HEADER);
-		this.annotatedWorker = new AnnotatedWorker(sequenceDiagram, sequenceDiagram.getSkinParam());
+		this.annotatedWorker = new AnnotatedWorker(diagram, diagram.getSkinParam(), stringBounder);
 
-		this.main = new MainTileAdapter(createMainTile());
-		this.min1 = ((MainTileAdapter) main).getMinX(stringBounder);
+		this.min1 = body.getMinX(stringBounder);
 
 		this.title = getTitle();
 		this.legend = getLegend();
 		this.caption = annotatedWorker.getCaption();
 
-		this.heightEnglober1 = englobers.getOffsetForEnglobers(stringBounder);
+		this.heightEnglober1 = dolls.getOffsetForEnglobers(stringBounder);
 		this.heightEnglober2 = heightEnglober1 == 0 ? 0 : 10;
 
-		final double totalWidth = MathUtils.max(main.calculateDimension(stringBounder).getWidth(), title
-				.calculateDimension(stringBounder).getWidth(), footer.calculateDimension(stringBounder).getWidth(),
-				header.calculateDimension(stringBounder).getWidth(), legend.calculateDimension(stringBounder)
-						.getWidth());
-		final double totalHeight = main.calculateDimension(stringBounder).getHeight() + heightEnglober1
+		final double totalWidth = MathUtils.max(body.calculateDimension(stringBounder).getWidth(),
+				title.calculateDimension(stringBounder).getWidth(), footer.calculateDimension(stringBounder).getWidth(),
+				header.calculateDimension(stringBounder).getWidth(),
+				legend.calculateDimension(stringBounder).getWidth());
+		final double totalHeight = body.calculateDimension(stringBounder).getHeight() + heightEnglober1
 				+ heightEnglober2 + title.calculateDimension(stringBounder).getHeight()
 				+ header.calculateDimension(stringBounder).getHeight()
 				+ legend.calculateDimension(stringBounder).getHeight()
-				+ footer.calculateDimension(stringBounder).getHeight();
+				+ caption.calculateDimension(stringBounder).getHeight()
+				+ footer.calculateDimension(stringBounder).getHeight() + (annotatedWorker.hasMainFrame() ? 10 : 0);
 		this.dimTotal = new Dimension2DDouble(totalWidth, totalHeight);
-
 	}
 
-	private Englobers englobers;
+	private Dolls dolls;
 	private final StringBounder stringBounder;
 
 	private final TextBlock footer;
 	private final TextBlock header;
 
-	private final TextBlock main;
+	private final PlayingSpaceWithParticipants body;
 
 	private final TextBlock title;
 	private final TextBlock legend;
@@ -127,59 +133,26 @@ public class SequenceDiagramFileMakerTeoz implements FileMaker {
 	private final double heightEnglober1;
 	private final double heightEnglober2;
 
-	private double oneOf(double a, double b) {
-		if (a == 1) {
-			return b;
+	public ImageData createOne(OutputStream os, final int index, boolean isWithMetadata) throws IOException {
+		if (this.index != index) {
+			throw new IllegalStateException();
 		}
-		return a;
+		return diagram.createImageBuilder(fileFormatOption)
+				.drawable(new Foo(index))
+				.write(os);
 	}
 
-	public ImageData createOne(OutputStream os, int index, boolean isWithMetadata) throws IOException {
-		final UTranslate min1translate = new UTranslate(-min1.getCurrentValue(), 0);
-		final double dpiFactor = diagram.getDpiFactor(fileFormatOption, dimTotal);
+	class Foo implements UDrawable {
 
-		final double scale = 1;
-		final String metadata = fileFormatOption.isWithMetadata() ? diagram.getMetadata() : null;
+		private final int index;
 
-		final ImageBuilder imageBuilder = new ImageBuilder(diagram.getSkinParam(), oneOf(scale, dpiFactor), metadata,
-				null, 3, 10, diagram.getAnimation());
+		Foo(int index) {
+			this.index = index;
+		}
 
-		imageBuilder.setUDrawable(new UDrawable() {
-
-			public void drawU(UGraphic ug) {
-				ug = ug.apply(min1translate);
-
-				englobers.drawEnglobers(goDownAndCenterForEnglobers(ug), main.calculateDimension(stringBounder)
-						.getHeight() + heightEnglober1 + heightEnglober2 / 2, new SimpleContext2D(true));
-
-				printAligned(ug, diagram.getFooterOrHeaderTeoz(FontParam.HEADER).getHorizontalAlignment(), header);
-				ug = goDown(ug, header);
-
-				printAligned(ug, HorizontalAlignment.CENTER, title);
-				ug = goDown(ug, title);
-
-				if (diagram.getLegend().getVerticalAlignment() == VerticalAlignment.TOP) {
-					printAligned(ug, diagram.getLegend().getHorizontalAlignment(), legend);
-					ug = goDown(ug, legend);
-				}
-
-				ug = ug.apply(new UTranslate(0, heightEnglober1));
-				printAligned(ug, HorizontalAlignment.CENTER, main);
-				ug = goDown(ug, main);
-				ug = ug.apply(new UTranslate(0, heightEnglober2));
-
-				printAligned(ug, HorizontalAlignment.CENTER, caption);
-
-				if (diagram.getLegend().getVerticalAlignment() == VerticalAlignment.BOTTOM) {
-					printAligned(ug, diagram.getLegend().getHorizontalAlignment(), legend);
-					ug = goDown(ug, legend);
-				}
-
-				printAligned(ug, diagram.getFooterOrHeaderTeoz(FontParam.FOOTER).getHorizontalAlignment(), footer);
-
-			}
-		});
-		return imageBuilder.writeImageTOBEMOVED(fileFormatOption, diagram.seed(), os);
+		public void drawU(UGraphic ug) {
+			drawInternal(ug, index);
+		}
 
 	}
 
@@ -189,12 +162,12 @@ public class SequenceDiagramFileMakerTeoz implements FileMaker {
 		if (diagram.getLegend().getVerticalAlignment() == VerticalAlignment.TOP) {
 			ug = goDown(ug, legend);
 		}
-		final double dx = (dimTotal.getWidth() - main.calculateDimension(stringBounder).getWidth()) / 2;
-		return ug.apply(new UTranslate(dx, 0));
+		final double dx = (dimTotal.getWidth() - body.calculateDimension(stringBounder).getWidth()) / 2;
+		return ug.apply(UTranslate.dx(dx));
 	}
 
 	private UGraphic goDown(UGraphic ug, TextBlock size) {
-		return ug.apply(new UTranslate(0, size.calculateDimension(stringBounder).getHeight()));
+		return ug.apply(UTranslate.dy(size.calculateDimension(stringBounder).getHeight()));
 	}
 
 	public void printAligned(UGraphic ug, HorizontalAlignment align, final TextBlock layer) {
@@ -204,27 +177,27 @@ public class SequenceDiagramFileMakerTeoz implements FileMaker {
 		} else if (align == HorizontalAlignment.CENTER) {
 			dx = (dimTotal.getWidth() - layer.calculateDimension(stringBounder).getWidth()) / 2;
 		}
-		layer.drawU(ug.apply(new UTranslate(dx, 0)));
+		layer.drawU(ug.apply(UTranslate.dx(dx)));
 	}
 
-	private MainTile createMainTile() {
+	private PlayingSpace createMainTile() {
 		final RealOrigin origin = RealUtils.createOrigin();
 		Real currentPos = origin.addAtLeast(0);
 		for (Participant p : diagram.participants()) {
-			final LivingSpace livingSpace = new LivingSpace(p, diagram.getEnglober(p), skin, getSkinParam(),
-					currentPos, diagram.events());
+			final LivingSpace livingSpace = new LivingSpace(p, diagram.getEnglober(p), skin, getSkinParam(), currentPos,
+					diagram.events());
 			livingSpaces.put(p, livingSpace);
 			currentPos = livingSpace.getPosD(stringBounder).addAtLeast(0);
 		}
 
-		final TileArguments tileArguments = new TileArguments(stringBounder, livingSpaces, skin,
-				diagram.getSkinParam(), origin);
+		final TileArguments tileArguments = new TileArguments(stringBounder, livingSpaces, skin, diagram.getSkinParam(),
+				origin);
 
-		this.englobers = new Englobers(tileArguments);
-		final MainTile mainTile = new MainTile(diagram, englobers, tileArguments);
+		this.dolls = new Dolls(tileArguments);
+		final PlayingSpace mainTile = new PlayingSpace(diagram, dolls, tileArguments);
 		this.livingSpaces.addConstraints(stringBounder);
-		mainTile.addConstraints(stringBounder);
-		this.englobers.addConstraints(stringBounder);
+		mainTile.addConstraints();
+		this.dolls.addConstraints(stringBounder);
 		origin.compileNow();
 		tileArguments.setBordered(mainTile);
 		return mainTile;
@@ -238,9 +211,18 @@ public class SequenceDiagramFileMakerTeoz implements FileMaker {
 		if (diagram.getTitle().isNull()) {
 			return new ComponentAdapter(null);
 		}
-		final TextBlock compTitle = TextBlockUtils.title(new FontConfiguration(getSkinParam(),
-				FontParam.SEQUENCE_TITLE, null), diagram.getTitle().getDisplay(), getSkinParam());
-		return TextBlockUtils.withMargin(compTitle, 7, 7);
+		final TextBlock compTitle;
+		if (UseStyle.useBetaStyle()) {
+			final Style style = StyleSignature.of(SName.root, SName.document, SName.title)
+					.getMergedStyle(diagram.getSkinParam().getCurrentStyleBuilder());
+			compTitle = style.createTextBlockBordered(diagram.getTitle().getDisplay(),
+					diagram.getSkinParam().getIHtmlColorSet(), diagram.getSkinParam());
+			return compTitle;
+		} else {
+			compTitle = TextBlockUtils.title(new FontConfiguration(getSkinParam(), FontParam.TITLE, null),
+					diagram.getTitle().getDisplay(), getSkinParam());
+			return TextBlockUtils.withMargin(compTitle, 7, 7);
+		}
 	}
 
 	private TextBlock getLegend() {
@@ -255,18 +237,67 @@ public class SequenceDiagramFileMakerTeoz implements FileMaker {
 		if (diagram.getFooterOrHeaderTeoz(param).isNull()) {
 			return new TeozLayer(null, stringBounder, param);
 		}
-		final DisplaySection display = diagram.getFooterOrHeaderTeoz(param);
-		final HtmlColor hyperlinkColor = getSkinParam().getHyperlinkColor();
-		final HtmlColor titleColor = getSkinParam().getFontHtmlColor(null, param);
+		final DisplaySection display = diagram.getFooterOrHeaderTeoz(param).withPage(index + 1, getNbPages());
+		final HColor hyperlinkColor = getSkinParam().getHyperlinkColor();
+		final HColor titleColor = getSkinParam().getFontHtmlColor(null, param);
 		final String fontFamily = getSkinParam().getFont(null, false, param).getFamily(null);
 		final int fontSize = getSkinParam().getFont(null, false, param).getSize();
+		Style style = null;
+		final ISkinParam skinParam = diagram.getSkinParam();
+		if (UseStyle.useBetaStyle()) {
+			final StyleSignature def = param.getStyleDefinition(null);
+			style = def.getMergedStyle(skinParam.getCurrentStyleBuilder());
+		}
 		final PngTitler pngTitler = new PngTitler(titleColor, display, fontSize, fontFamily, hyperlinkColor,
-				getSkinParam().useUnderlineForHyperlink());
+				getSkinParam().useUnderlineForHyperlink(), style, skinParam.getIHtmlColorSet(), skinParam);
 		return new TeozLayer(pngTitler, stringBounder, param);
 	}
 
 	public int getNbPages() {
-		return 1;
+		return body.getNbPages();
+	}
+
+	private void drawInternal(UGraphic ug, int index) {
+		body.setIndex(index);
+		final UTranslate min1translate = UTranslate.dx(-min1.getCurrentValue());
+		ug = ug.apply(min1translate);
+
+		dolls.drawEnglobers(goDownAndCenterForEnglobers(ug),
+				body.calculateDimension(stringBounder).getHeight() + heightEnglober1 + heightEnglober2 / 2,
+				new SimpleContext2D(true));
+
+		printAligned(ug, diagram.getFooterOrHeaderTeoz(FontParam.HEADER).getHorizontalAlignment(), header);
+		ug = goDown(ug, header);
+
+		HorizontalAlignment titleAlignment = HorizontalAlignment.CENTER;
+		if (UseStyle.useBetaStyle()) {
+			final StyleSignature def = FontParam.TITLE.getStyleDefinition(null);
+			titleAlignment = def.getMergedStyle(diagram.getSkinParam().getCurrentStyleBuilder())
+					.getHorizontalAlignment();
+		}
+		printAligned(ug, titleAlignment, title);
+		ug = goDown(ug, title);
+
+		if (diagram.getLegend().getVerticalAlignment() == VerticalAlignment.TOP) {
+			printAligned(ug, diagram.getLegend().getHorizontalAlignment(), legend);
+			ug = goDown(ug, legend);
+		}
+
+		ug = ug.apply(UTranslate.dy(heightEnglober1));
+		final TextBlock bodyFramed = annotatedWorker.addFrame(body);
+		printAligned(ug.apply(UTranslate.dx((annotatedWorker.hasMainFrame() ? 4 : 0))), HorizontalAlignment.CENTER,
+				bodyFramed);
+		ug = goDown(ug, bodyFramed);
+		ug = ug.apply(UTranslate.dy(heightEnglober2));
+
+		if (diagram.getLegend().getVerticalAlignment() == VerticalAlignment.BOTTOM) {
+			printAligned(ug, diagram.getLegend().getHorizontalAlignment(), legend);
+			ug = goDown(ug, legend);
+		}
+		printAligned(ug, HorizontalAlignment.CENTER, caption);
+		ug = goDown(ug, caption);
+
+		printAligned(ug, diagram.getFooterOrHeaderTeoz(FontParam.FOOTER).getHorizontalAlignment(), footer);
 	}
 
 }
