@@ -47,6 +47,7 @@ import net.sourceforge.plantuml.command.Command;
 import net.sourceforge.plantuml.command.CommandFootboxIgnored;
 import net.sourceforge.plantuml.command.CommandRankDir;
 import net.sourceforge.plantuml.command.PSystemCommandFactory;
+import net.sourceforge.plantuml.command.CommonCommands;
 import net.sourceforge.plantuml.command.note.CommandFactoryNote;
 import net.sourceforge.plantuml.command.note.CommandFactoryNoteOnEntity;
 import net.sourceforge.plantuml.command.note.CommandFactoryNoteOnLink;
@@ -55,6 +56,7 @@ import net.sourceforge.plantuml.command.regex.RegexOr;
 import net.sourceforge.plantuml.core.UmlSource;
 import net.sourceforge.plantuml.statediagram.command.CommandAddField;
 import net.sourceforge.plantuml.statediagram.command.CommandConcurrentState;
+import net.sourceforge.plantuml.statediagram.command.CommandCreatePackage2;
 import net.sourceforge.plantuml.statediagram.command.CommandCreatePackageState;
 import net.sourceforge.plantuml.statediagram.command.CommandCreateState;
 import net.sourceforge.plantuml.statediagram.command.CommandEndState;
@@ -78,6 +80,7 @@ public class StateDiagramFactory extends PSystemCommandFactory {
 		cmds.add(new CommandLinkState());
 		cmds.add(new CommandLinkStateReverse());
 		cmds.add(new CommandCreatePackageState());
+		cmds.add(new CommandCreatePackage2());
 		cmds.add(new CommandEndState());
 		cmds.add(new CommandAddField());
 		cmds.add(new CommandConcurrentState());
@@ -99,7 +102,7 @@ public class StateDiagramFactory extends PSystemCommandFactory {
 		cmds.add(factoryNoteCommand.createSingleLine());
 		cmds.add(factoryNoteCommand.createMultiLine(false));
 
-		addCommonCommands1(cmds);
+		CommonCommands.addCommonCommands1(cmds);
 		cmds.add(new CommandHideShow2());
 		cmds.add(new CommandNamespaceSeparator());
 
