@@ -101,9 +101,9 @@ public class CommandCreatePackageState extends SingleLineCommand2<StateDiagram>
 	}
 
 	private String getNotNull(RegexResult arg, String v1, String v2) {
-		if (arg.get(v1, 0) == null) {
+		if (arg.get(v1, 0) == null)
 			return arg.get(v2, 0);
-		}
+
 		return arg.get(v1, 0);
 	}
 
@@ -115,16 +115,16 @@ public class CommandCreatePackageState extends SingleLineCommand2<StateDiagram>
 		final Ident idNewLong = diagram.buildLeafIdentSpecial(idShort);
 		final Code code = diagram.V1972() ? idNewLong : diagram.buildCode(idShort);
 		String display = getNotNull(arg, "DISPLAY1", "DISPLAY2");
-		if (display == null) {
+		if (display == null)
 			display = code.getName();
-		}
+
 		diagram.gotoGroup(idNewLong, code, Display.getWithNewlines(display), GroupType.STATE, currentPackage,
 				NamespaceStrategy.SINGLE);
 		final IEntity p = diagram.getCurrentGroup();
 		final String stereotype = arg.get("STEREOTYPE", 0);
-		if (stereotype != null) {
+		if (stereotype != null)
 			p.setStereotype(Stereotype.build(stereotype));
-		}
+
 		final String urlString = arg.get("URL", 0);
 		if (urlString != null) {
 			final UrlBuilder urlBuilder = new UrlBuilder(diagram.getSkinParam().getValue("topurl"), ModeUrl.STRICT);
@@ -138,21 +138,13 @@ public class CommandCreatePackageState extends SingleLineCommand2<StateDiagram>
 
 		final HColor lineColor = s == null ? null
 				: diagram.getSkinParam().getIHtmlColorSet().getColor(diagram.getSkinParam().getThemeStyle(), s);
-		if (lineColor != null) {
+		if (lineColor != null)
 			colors = colors.add(ColorType.LINE, lineColor);
-		}
-		if (arg.get("LINECOLOR", 0) != null) {
-			colors = colors.addLegacyStroke(arg.get("LINECOLOR", 0));
-		}
-		p.setColors(colors);
 
-		// p.setSpecificColorTOBEREMOVED(ColorType.BACK,
-		// diagram.getSkinParam().getIHtmlColorSet().getColorIfValid(arg.get("COLOR",
-		// 0)));
-		// p.setSpecificColorTOBEREMOVED(ColorType.LINE,
-		// diagram.getSkinParam().getIHtmlColorSet().getColorIfValid(arg.get("LINECOLOR",
-		// 1)));
-		// p.applyStroke(arg.get("LINECOLOR", 0));
+		if (arg.get("LINECOLOR", 0) != null)
+			colors = colors.addLegacyStroke(arg.get("LINECOLOR", 0));
+
+		p.setColors(colors);
 		return CommandExecutionResult.ok();
 	}
 
