@@ -68,6 +68,8 @@ public enum SName {
 	document, //
 	element, //
 	entity, //
+	end, //
+	stop, //
 	file, //
 	folder, //
 	footer, //
@@ -118,8 +120,23 @@ public enum SName {
 	timeline, //
 	timingDiagram, //
 	title, //
+	undone, //
 	unstarted, //
 	usecase, //
+	
+	visibilityIcon, //
+	private_, //
+	protected_, //
+	public_, //
+	IEMandatory, //
+	spot, //
+	spotAnnotation, //
+	spotInterface, //
+	spotEnum, //
+	spotEntity, //
+	spotClass, //
+	spotAbstractClass, //
+	
 	wbsDiagram, //
 	yamlDiagram; //
 
