@@ -43,6 +43,7 @@ import java.util.Collections;
 import java.util.EnumMap;
 import java.util.List;
 import java.util.Map;
+import java.util.Map.Entry;
 
 import net.sourceforge.plantuml.FileSystem;
 import net.sourceforge.plantuml.LineLocationImpl;
@@ -68,23 +69,7 @@ public class StyleLoader {
 	public StyleBuilder loadSkin(String filename) throws IOException {
 		this.styleBuilder = new StyleBuilder(skinParam);
 
-		InputStream internalIs = null;
-		SFile localFile = new SFile(filename);
-		Log.info("Trying to load style " + filename);
-		if (localFile.exists() == false) {
-			localFile = FileSystem.getInstance().getFile(filename);
-		}
-		if (localFile.exists()) {
-			Log.info("File found : " + localFile.getPrintablePath());
-			internalIs = localFile.openFile();
-		} else {
-			Log.info("File not found : " + localFile.getPrintablePath());
-			final String res = "/skin/" + filename;
-			internalIs = StyleLoader.class.getResourceAsStream(res);
-			if (internalIs != null) {
-				Log.info("... but " + filename + " found inside the .jar");
-			}
-		}
+		final InputStream internalIs = getInputStreamForStyle(filename);
 		if (internalIs == null) {
 			Log.error("No .skin file seems to be available");
 			throw new NoStyleAvailableException();
@@ -98,20 +83,42 @@ public class StyleLoader {
 		return this.styleBuilder;
 	}
 
-	private void loadSkinInternal(final BlocLines lines) {
-		for (Style newStyle : getDeclaredStyles(lines, styleBuilder)) {
-			this.styleBuilder.loadInternal(newStyle.getSignature(), newStyle);
+	public static InputStream getInputStreamForStyle(String filename) throws IOException {
+		InputStream internalIs = null;
+		SFile localFile = new SFile(filename);
+		Log.info("Trying to load style " + filename);
+		if (localFile.exists() == false)
+			localFile = FileSystem.getInstance().getFile(filename);
+
+		if (localFile.exists()) {
+			Log.info("File found : " + localFile.getPrintablePath());
+			internalIs = localFile.openFile();
+		} else {
+			Log.info("File not found : " + localFile.getPrintablePath());
+			final String res = "/skin/" + filename;
+			internalIs = StyleLoader.class.getResourceAsStream(res);
+			if (internalIs != null)
+				Log.info("... but " + filename + " found inside the .jar");
+
 		}
+		return internalIs;
 	}
 
-	private final static String KEYNAMES = "[\\w(), ]+?";
-	private final static Pattern2 keyName = MyPattern.cmpile("^[.:]?(" + KEYNAMES + ")([%s]+\\*)?[%s]*\\{$");
+	private void loadSkinInternal(final BlocLines lines) {
+		for (Style newStyle : getDeclaredStyles(lines, styleBuilder))
+			this.styleBuilder.loadInternal(newStyle.getSignature(), newStyle);
+
+	}
+
+	private final static String KEYNAMES = "[.\\w(), ]+?";
+	private final static Pattern2 keyName = MyPattern.cmpile("^[:]?(" + KEYNAMES + ")([%s]+\\*)?[%s]*\\{$");
 	private final static Pattern2 propertyAndValue = MyPattern.cmpile("^([\\w]+):?[%s]+(.*?);?$");
 	private final static Pattern2 closeBracket = MyPattern.cmpile("^\\}$");
 
 	public static Collection<Style> getDeclaredStyles(BlocLines lines, AutomaticCounter counter) {
 		lines = lines.eventuallyMoveAllEmptyBracket();
 		final List<Style> result = new ArrayList<>();
+		StyleScheme scheme = StyleScheme.REGULAR;
 
 		Context context = new Context();
 		final List<Map<PName, Value>> maps = new ArrayList<Map<PName, Value>>();
@@ -134,28 +141,33 @@ public class StyleLoader {
 			if (inComment)
 				continue;
 
-			final int x = trimmed.lastIndexOf("//");
-			if (x != -1) {
-				trimmed = trimmed.substring(0, x).trim();
+			if (trimmed.matches("@media.*dark.*\\{")) {
+				scheme = StyleScheme.DARK;
+				continue;
 			}
+
+			final int x = trimmed.lastIndexOf("//");
+			if (x != -1)
+				trimmed = trimmed.substring(0, x).trim();
+
 			final Matcher2 mKeyNames = keyName.matcher(trimmed);
 			if (mKeyNames.find()) {
 				String names = mKeyNames.group(1).replace(" ", "");
 				final boolean isRecurse = mKeyNames.group(2) != null;
-				if (isRecurse) {
+				if (isRecurse)
 					names += "*";
-				}
+
 				context = context.push(names);
 				maps.add(new EnumMap<PName, Value>(PName.class));
 				continue;
 			}
 			final Matcher2 mPropertyAndValue = propertyAndValue.matcher(trimmed);
 			if (mPropertyAndValue.find()) {
-				final PName key = PName.getFromName(mPropertyAndValue.group(1));
+				final PName key = PName.getFromName(mPropertyAndValue.group(1), scheme);
 				final String value = mPropertyAndValue.group(2);
-				if (key != null && maps.size() > 0) {
+				if (key != null && maps.size() > 0)
 					maps.get(maps.size() - 1).put(key, new ValueImpl(value, counter));
-				}
+
 				continue;
 			}
 			final Matcher2 mCloseBracket = closeBracket.matcher(trimmed);
@@ -163,11 +175,18 @@ public class StyleLoader {
 				if (context.size() > 0) {
 					final Collection<StyleSignature> signatures = context.toSignatures();
 					for (StyleSignature signature : signatures) {
-						final Style style = new Style(signature, maps.get(maps.size() - 1));
-						result.add(style);
+						Map<PName, Value> tmp = maps.get(maps.size() - 1);
+						if (signature.isWithDot())
+							tmp = addPriority(tmp);
+						if (tmp.size() > 0) {
+							final Style style = new Style(signature, tmp);
+							result.add(style);
+						}
 					}
 					context = context.pop();
 					maps.remove(maps.size() - 1);
+				} else {
+					scheme = StyleScheme.REGULAR;
 				}
 			}
 		}
@@ -176,4 +195,12 @@ public class StyleLoader {
 
 	}
 
+	private static Map<PName, Value> addPriority(Map<PName, Value> tmp) {
+		final Map<PName, Value> result = new EnumMap<>(PName.class);
+		for (Entry<PName, Value> ent : tmp.entrySet())
+			result.put(ent.getKey(), ((ValueImpl) ent.getValue()).addPriority(1000));
+
+		return result;
+	}
+
 }
\ No newline at end of file
