@@ -130,11 +130,10 @@ public class Cluster implements Moveable {
 
 	private Set<EntityPosition> entityPositionsExceptNormal() {
 		final Set<EntityPosition> result = EnumSet.<EntityPosition>noneOf(EntityPosition.class);
-		for (SvekNode sh : nodes) {
-			if (sh.getEntityPosition() != EntityPosition.NORMAL) {
+		for (SvekNode sh : nodes)
+			if (sh.getEntityPosition() != EntityPosition.NORMAL)
 				result.add(sh.getEntityPosition());
-			}
-		}
+
 		return Collections.unmodifiableSet(result);
 	}
 
@@ -145,14 +144,14 @@ public class Cluster implements Moveable {
 	private ColorParam border;
 
 	private Cluster(Cluster parentCluster, ColorSequence colorSequence, ISkinParam skinParam, IGroup group) {
-		if (group == null) {
+		if (group == null)
 			throw new IllegalStateException();
-		}
+
 		this.parentCluster = parentCluster;
 		this.group = group;
-		if (group.getUSymbol() != null) {
+		if (group.getUSymbol() != null)
 			border = group.getUSymbol().getColorParamBorder();
-		}
+
 		this.color = colorSequence.getValue();
 		this.colorTitle = colorSequence.getValue();
 		this.skinParam = group.getColors().mute(skinParam);
@@ -193,16 +192,14 @@ public class Cluster implements Moveable {
 		for (SvekLine l : lines) {
 			if (tops.contains(l.getStartUidPrefix())) {
 				final SvekNode sh = shs.get(l.getEndUidPrefix());
-				if (sh != null && sh.getEntityPosition() == EntityPosition.NORMAL) {
+				if (sh != null && sh.getEntityPosition() == EntityPosition.NORMAL)
 					firsts.add(0, sh);
-				}
 			}
 
 			if (l.isInverted()) {
 				final SvekNode sh = shs.get(l.getStartUidPrefix());
-				if (sh != null && sh.getEntityPosition() == EntityPosition.NORMAL) {
+				if (sh != null && sh.getEntityPosition() == EntityPosition.NORMAL)
 					firsts.add(0, sh);
-				}
 			}
 		}
 
@@ -230,16 +227,14 @@ public class Cluster implements Moveable {
 		for (SvekLine l : lines) {
 			if (tops.contains(l.getStartUidPrefix())) {
 				final SvekNode sh = shs.get(l.getEndUidPrefix());
-				if (sh != null) {
+				if (sh != null)
 					all.remove(sh);
-				}
 			}
 
 			if (l.isInverted()) {
 				final SvekNode sh = shs.get(l.getStartUidPrefix());
-				if (sh != null) {
+				if (sh != null)
 					all.remove(sh);
-				}
 			}
 		}
 
@@ -294,10 +289,12 @@ public class Cluster implements Moveable {
 		return SkinParamUtils.getColor(skinParam, stereotype, colorParam);
 	}
 
-	static public StyleSignature getDefaultStyleDefinition(SName styleName) {
-		if (styleName == SName.stateDiagram)
+	static public StyleSignature getDefaultStyleDefinition(SName diagramStyleName, USymbol symbol) {
+		if (diagramStyleName == SName.stateDiagram)
 			return StyleSignature.of(SName.root, SName.element, SName.stateDiagram, SName.state, SName.group);
-		return StyleSignature.of(SName.root, SName.element, styleName, SName.group);
+		if (symbol == null)
+			return StyleSignature.of(SName.root, SName.element, diagramStyleName, SName.group);
+		return StyleSignature.of(SName.root, SName.element, diagramStyleName, SName.group, symbol.getSName());
 	}
 
 	static public StyleSignature getDefaultStyleDefinitionStateGroup(Stereotype stereotype) {
@@ -308,86 +305,91 @@ public class Cluster implements Moveable {
 	}
 
 	public void drawU(UGraphic ug, UStroke strokeForState, UmlDiagramType umlDiagramType, ISkinParam skinParam2) {
-		if (group.isHidden()) {
+		if (group.isHidden())
 			return;
-		}
+
 		final String fullName = group.getCodeGetName();
-		if (fullName.startsWith("##") == false) {
+		if (fullName.startsWith("##") == false)
 			ug.draw(new UComment("cluster " + fullName));
-		}
+
 		HColor borderColor;
 		Style style = null;
 		final double rounded;
 		final double shadowing;
 		if (UseStyle.useBetaStyle()) {
-			style = getDefaultStyleDefinition(umlDiagramType.getStyleName()).with(group.getStereotype())
-					.getMergedStyle(skinParam.getCurrentStyleBuilder());
+			final USymbol uSymbol = group.getUSymbol() == null ? USymbol.PACKAGE : group.getUSymbol();
+			final StyleSignature tmp = getDefaultStyleDefinition(umlDiagramType.getStyleName(), uSymbol);
+			style = tmp.with(group.getStereotype()).getMergedStyle(skinParam.getCurrentStyleBuilder());
 			shadowing = style.value(PName.Shadowing).asDouble();
-			borderColor = style.value(PName.LineColor).asColor(skinParam2.getThemeStyle(),
-					skinParam2.getIHtmlColorSet());
+			if (group.getColors().getColor(ColorType.LINE) != null)
+				borderColor = group.getColors().getColor(ColorType.LINE);
+			else
+				borderColor = style.value(PName.LineColor).asColor(skinParam2.getThemeStyle(),
+						skinParam2.getIHtmlColorSet());
 			if (umlDiagramType == UmlDiagramType.STATE)
 				rounded = style.value(PName.RoundCorner).asDouble();
 			else
 				rounded = IEntityImage.CORNER;
 
 		} else {
-			if (group.getUSymbol() == null) {
+			if (group.getUSymbol() == null)
 				shadowing = skinParam2.shadowing2(group.getStereotype(), USymbol.PACKAGE.getSkinParameter()) ? 3 : 0;
-			} else {
+			else
 				shadowing = skinParam2.shadowing2(group.getStereotype(), group.getUSymbol().getSkinParameter()) ? 3 : 0;
-			}
+
 			rounded = IEntityImage.CORNER;
-			if (umlDiagramType == UmlDiagramType.STATE) {
+			if (umlDiagramType == UmlDiagramType.STATE)
 				borderColor = getColor(ColorParam.stateBorder, skinParam, group.getStereotype());
-			} else if (umlDiagramType == UmlDiagramType.ACTIVITY) {
+			else if (umlDiagramType == UmlDiagramType.ACTIVITY)
 				borderColor = getColor(ColorParam.packageBorder, skinParam, group.getStereotype());
-			} else {
+			else
 				borderColor = getColor(ColorParam.packageBorder, skinParam, group.getStereotype());
-			}
+
 		}
 
 		final Url url = group.getUrl99();
-		if (url != null) {
+		if (url != null)
 			ug.startUrl(url);
-		}
+
 		try {
-			if (entityPositionsExceptNormal().size() > 0) {
+			if (entityPositionsExceptNormal().size() > 0)
 				manageEntryExitPoint(ug.getStringBounder());
-			}
+
 			if (skinParam.useSwimlanes(umlDiagramType)) {
 				drawSwinLinesState(ug, borderColor);
 				return;
 			}
 			final boolean isState = umlDiagramType == UmlDiagramType.STATE;
-			if (isState) {
-				if (group.getColors().getSpecificLineStroke() != null) {
+
+			if (isState && group.getUSymbol() == null) {
+				if (group.getColors().getSpecificLineStroke() != null)
 					strokeForState = group.getColors().getSpecificLineStroke();
-				}
-				if (group.getColors().getColor(ColorType.LINE) != null) {
+
+				if (group.getColors().getColor(ColorType.LINE) != null)
 					borderColor = group.getColors().getColor(ColorType.LINE);
-				}
+
 				drawUState(ug, borderColor, skinParam2, strokeForState, umlDiagramType, rounded, shadowing);
 				return;
 			}
 			PackageStyle packageStyle = group.getPackageStyle();
-			if (packageStyle == null) {
+			if (packageStyle == null)
 				packageStyle = skinParam2.packageStyle();
-			}
+
 			if (border != null) {
 				final HColor tmp = skinParam2.getHtmlColor(border, group.getStereotype(), false);
-				if (tmp != null) {
+				if (tmp != null)
 					borderColor = tmp;
-				}
 			}
 
 			final UStroke stroke;
-			if (UseStyle.useBetaStyle()) {
+			if (UseStyle.useBetaStyle())
 				stroke = getStrokeInternal(group, skinParam2, style);
-			} else {
+			else
 				stroke = getStrokeInternal(group, skinParam2, null);
-			}
+
 			HColor backColor = getBackColor(umlDiagramType, style);
-			backColor = getBackColor(backColor, skinParam2, group.getStereotype(), umlDiagramType.getStyleName());
+			backColor = getBackColor(backColor, skinParam2, group.getStereotype(), umlDiagramType.getStyleName(),
+					group.getUSymbol());
 			if (ztitle != null || zstereo != null) {
 				final double roundCorner = group.getUSymbol() == null ? 0
 						: group.getUSymbol().getSkinParameter().getRoundCorner(skinParam, group.getStereotype());
@@ -405,44 +407,42 @@ public class Cluster implements Moveable {
 			ug.apply(new UStroke(2)).apply(new UTranslate(minX, minY)).draw(rect);
 
 		} finally {
-			if (url != null) {
+			if (url != null)
 				ug.closeUrl();
-			}
 		}
 
 	}
 
 	static public UStroke getStrokeInternal(IGroup group, ISkinParam skinParam, Style style) {
 		final Colors colors = group.getColors();
-		if (colors.getSpecificLineStroke() != null) {
+		if (colors.getSpecificLineStroke() != null)
 			return colors.getSpecificLineStroke();
-		}
-		if (style != null) {
+
+		if (style != null)
 			return style.getStroke();
-		}
-		if (group.getUSymbol() != null && group.getUSymbol() != USymbol.PACKAGE) {
+
+		if (group.getUSymbol() != null && group.getUSymbol() != USymbol.PACKAGE)
 			return group.getUSymbol().getSkinParameter().getStroke(skinParam, group.getStereotype());
-		}
+
 		return GeneralImageBuilder.getForcedStroke(group.getStereotype(), skinParam);
 	}
 
 	public void manageEntryExitPoint(StringBounder stringBounder) {
 		final Collection<ClusterPosition> insides = new ArrayList<>();
 		final List<Point2D> points = new ArrayList<>();
-		for (SvekNode sh : nodes) {
-			if (sh.getEntityPosition() == EntityPosition.NORMAL) {
+		for (SvekNode sh : nodes)
+			if (sh.getEntityPosition() == EntityPosition.NORMAL)
 				insides.add(sh.getClusterPosition());
-			} else {
+			else
 				points.add(sh.getClusterPosition().getPointCenter());
-			}
-		}
-		for (Cluster in : children) {
+
+		for (Cluster in : children)
 			insides.add(in.getClusterPosition());
-		}
+
 		final FrontierCalculator frontierCalculator = new FrontierCalculator(getClusterPosition(), insides, points);
-		if (titleAndAttributeHeight > 0 && titleAndAttributeWidth > 0) {
+		if (titleAndAttributeHeight > 0 && titleAndAttributeWidth > 0)
 			frontierCalculator.ensureMinWidth(titleAndAttributeWidth + 10);
-		}
+
 		final ClusterPosition forced = frontierCalculator.getSuggestedPosition();
 		xTitle += ((forced.getMinX() - minX) + (forced.getMaxX() - maxX)) / 2;
 		minX = forced.getMinX();
@@ -455,9 +455,9 @@ public class Cluster implements Moveable {
 	}
 
 	private void drawSwinLinesState(UGraphic ug, HColor borderColor) {
-		if (ztitle != null) {
+		if (ztitle != null)
 			ztitle.drawU(ug.apply(UTranslate.dx(xTitle)));
-		}
+
 		final ULine line = ULine.vline(maxY - minY);
 		ug = ug.apply(borderColor);
 		ug.apply(UTranslate.dx(minX)).draw(line);
@@ -473,20 +473,19 @@ public class Cluster implements Moveable {
 			UmlDiagramType umlDiagramType, double rounded, double shadowing) {
 		final Dimension2D total = new Dimension2DDouble(maxX - minX, maxY - minY);
 		final double suppY;
-		if (ztitle == null) {
+		if (ztitle == null)
 			suppY = 0;
-		} else {
+		else
 			suppY = ztitle.calculateDimension(ug.getStringBounder()).getHeight() + IEntityImage.MARGIN
 					+ IEntityImage.MARGIN_LINE;
-		}
 
 		final Style styleGroup = getDefaultStyleDefinitionStateGroup(group.getStereotype())
 				.getMergedStyle(skinParam.getCurrentStyleBuilder());
 
 		HColor stateBack = getBackColor(umlDiagramType, styleGroup);
-		if (stateBack == null) {
+		if (stateBack == null)
 			stateBack = getColorLegacy(skinParam2, ColorParam.stateBackground, group.getStereotype());
-		}
+
 		final HColor background = getColorLegacy(skinParam2, ColorParam.background, null);
 
 		// final Style style = getStyle(FontParam.STATE_ATTRIBUTE, skinParam2);
@@ -502,20 +501,17 @@ public class Cluster implements Moveable {
 				stroke, rounded, shadowing);
 		r.drawU(ug.apply(new UTranslate(minX, minY)));
 
-		if (ztitle != null) {
+		if (ztitle != null)
 			ztitle.drawU(ug.apply(new UTranslate(xTitle, yTitle)));
-		}
 
-		if (attributeHeight > 0) {
+		if (attributeHeight > 0)
 			attribute.drawU(
 					ug.apply(new UTranslate(minX + IEntityImage.MARGIN, minY + suppY + IEntityImage.MARGIN / 2.0)));
-		}
 
 		final Stereotype stereotype = group.getStereotype();
 		final boolean withSymbol = stereotype != null && stereotype.isWithOOSymbol();
-		if (withSymbol) {
+		if (withSymbol)
 			EntityImageState.drawSymbol(ug.apply(borderColor), maxX, maxY);
-		}
 
 	}
 
@@ -531,18 +527,17 @@ public class Cluster implements Moveable {
 	}
 
 	private boolean isThereALinkFromOrToGroup(Collection<SvekLine> lines) {
-		for (SvekLine line : lines) {
-			if (line.isLinkFromOrTo(group)) {
+		for (SvekLine line : lines)
+			if (line.isLinkFromOrTo(group))
 				return true;
-			}
-		}
+
 		return false;
 	}
 
 	public void printCluster1(StringBuilder sb, Collection<SvekLine> lines, StringBounder stringBounder) {
-		for (SvekNode node : getNodesOrderedTop(lines)) {
+		for (SvekNode node : getNodesOrderedTop(lines))
 			node.appendShape(sb, stringBounder);
-		}
+
 	}
 
 	private List<IShapePseudo> addProtection(List<? extends IShapePseudo> entries, double width) {
@@ -560,9 +555,9 @@ public class Cluster implements Moveable {
 		double result = -Double.MAX_VALUE;
 		for (IShapePseudo node : entries) {
 			final double w = getMaxWidthFromLabelForEntryExit(node, stringBounder);
-			if (w > result) {
+			if (w > result)
 				result = w;
-			}
+
 		}
 		return result;
 	}
@@ -575,22 +570,22 @@ public class Cluster implements Moveable {
 			StringBounder stringBounder) {
 		if (entries.size() > 0) {
 			sb.append("{rank=" + rank + ";");
-			for (IShapePseudo sh1 : entries) {
+			for (IShapePseudo sh1 : entries)
 				sb.append(sh1.getUid() + ";");
-			}
+
 			sb.append("}");
 			SvekUtils.println(sb);
-			for (IShapePseudo sh2 : entries) {
+			for (IShapePseudo sh2 : entries)
 				sh2.appendShape(sb, stringBounder);
-			}
+
 			SvekUtils.println(sb);
 			if (hasPort()) {
 				boolean arrow = false;
 				String node = null;
 				for (IShapePseudo sh : entries) {
-					if (arrow) {
+					if (arrow)
 						sb.append("->");
-					}
+
 					arrow = true;
 					node = sh.getUid();
 					sb.append(node);
@@ -608,9 +603,9 @@ public class Cluster implements Moveable {
 		final List<SvekNode> result = withPosition(targets);
 		final double maxWith = getMaxWidthFromLabelForEntryExit(result, stringBounder);
 		final double naturalSpace = 70;
-		if (maxWith > naturalSpace) {
+		if (maxWith > naturalSpace)
 			return addProtection(result, maxWith - naturalSpace);
-		}
+
 		return result;
 	}
 
@@ -618,9 +613,9 @@ public class Cluster implements Moveable {
 		final List<SvekNode> result = new ArrayList<>();
 		for (final Iterator<SvekNode> it = nodes.iterator(); it.hasNext();) {
 			final SvekNode sh = it.next();
-			if (positions.contains(sh.getEntityPosition())) {
+			if (positions.contains(sh.getEntityPosition()))
 				result.add(sh);
-			}
+
 		}
 		return result;
 	}
@@ -641,13 +636,11 @@ public class Cluster implements Moveable {
 		}
 
 		if (skinParam.useRankSame() && dotMode != DotMode.NO_LEFT_RIGHT_AND_XLABEL
-				&& graphvizVersion.ignoreHorizontalLinks() == false) {
+				&& graphvizVersion.ignoreHorizontalLinks() == false)
 			appendRankSame(sb, lines);
-		}
 
-		for (Cluster child : getChildren()) {
+		for (Cluster child : getChildren())
 			child.printInternal(sb, lines, stringBounder, dotMode, graphvizVersion, type);
-		}
 
 		return added;
 	}
@@ -662,39 +655,36 @@ public class Cluster implements Moveable {
 	private Set<String> getRankSame(Collection<SvekLine> lines) {
 		final Set<String> rankSame = new HashSet<>();
 		for (SvekLine l : lines) {
-			if (l.hasEntryPoint()) {
+			if (l.hasEntryPoint())
 				continue;
-			}
+
 			final String startUid = l.getStartUidPrefix();
 			final String endUid = l.getEndUidPrefix();
 			if (isInCluster(startUid) && isInCluster(endUid)) {
 				final String same = l.rankSame();
-				if (same != null) {
+				if (same != null)
 					rankSame.add(same);
-				}
+
 			}
 		}
 		return rankSame;
 	}
 
 	public void fillRankMin(Set<String> rankMin) {
-		for (SvekNode sh : getNodes()) {
-			if (sh.isTop()) {
+		for (SvekNode sh : getNodes())
+			if (sh.isTop())
 				rankMin.add(sh.getUid());
-			}
-		}
 
-		for (Cluster child : getChildren()) {
+		for (Cluster child : getChildren())
 			child.fillRankMin(rankMin);
-		}
+
 	}
 
 	private boolean isInCluster(String uid) {
-		for (SvekNode node : nodes) {
-			if (node.getUid().equals(uid)) {
+		for (SvekNode node : nodes)
+			if (node.getUid().equals(uid))
 				return true;
-			}
-		}
+
 		return false;
 	}
 
@@ -707,47 +697,47 @@ public class Cluster implements Moveable {
 	}
 
 	private boolean protection0(UmlDiagramType type) {
-		if (skinParam.useSwimlanes(type)) {
+		if (skinParam.useSwimlanes(type))
 			return false;
-		}
+
 		return true;
 	}
 
 	private boolean protection1(UmlDiagramType type) {
-		if (group.getUSymbol() == USymbol.NODE) {
+		if (group.getUSymbol() == USymbol.NODE)
 			return true;
-		}
-		if (skinParam.useSwimlanes(type)) {
+
+		if (skinParam.useSwimlanes(type))
 			return false;
-		}
+
 		return true;
 	}
 
 	public String getMinPoint(UmlDiagramType type) {
-		if (skinParam.useSwimlanes(type)) {
+		if (skinParam.useSwimlanes(type))
 			return "minPoint" + color;
-		}
+
 		return null;
 	}
 
 	public String getMaxPoint(UmlDiagramType type) {
-		if (skinParam.useSwimlanes(type)) {
+		if (skinParam.useSwimlanes(type))
 			return "maxPoint" + color;
-		}
+
 		return null;
 	}
 
 	private String getSourceInPoint(UmlDiagramType type) {
-		if (skinParam.useSwimlanes(type)) {
+		if (skinParam.useSwimlanes(type))
 			return "sourceIn" + color;
-		}
+
 		return null;
 	}
 
 	private String getSinkInPoint(UmlDiagramType type) {
-		if (skinParam.useSwimlanes(type)) {
+		if (skinParam.useSwimlanes(type))
 			return "sinkIn" + color;
-		}
+
 		return null;
 	}
 
@@ -757,21 +747,19 @@ public class Cluster implements Moveable {
 		boolean thereALinkFromOrToGroup1 = thereALinkFromOrToGroup2;
 		final boolean useProtectionWhenThereALinkFromOrToGroup = graphvizVersion
 				.useProtectionWhenThereALinkFromOrToGroup();
-		if (useProtectionWhenThereALinkFromOrToGroup == false) {
+		if (useProtectionWhenThereALinkFromOrToGroup == false)
 			thereALinkFromOrToGroup1 = false;
-		}
+
 		// final boolean thereALinkFromOrToGroup1 = false;
-		if (thereALinkFromOrToGroup1) {
+		if (thereALinkFromOrToGroup1)
 			subgraphClusterNoLabel(sb, "a");
-		}
+
 		final Set<EntityPosition> entityPositionsExceptNormal = entityPositionsExceptNormal();
-		if (entityPositionsExceptNormal.size() > 0) {
-			for (SvekLine line : lines) {
-				if (line.isLinkFromOrTo(group)) {
+		if (entityPositionsExceptNormal.size() > 0)
+			for (SvekLine line : lines)
+				if (line.isLinkFromOrTo(group))
 					line.setProjectionCluster(this);
-				}
-			}
-		}
+
 		boolean protection0 = protection0(type);
 		boolean protection1 = protection1(type);
 		if (entityPositionsExceptNormal.size() > 0 || useProtectionWhenThereALinkFromOrToGroup == false) {
@@ -782,9 +770,9 @@ public class Cluster implements Moveable {
 		// protection0 = false;
 		// protection1 = false;
 		// }
-		if (protection0) {
+		if (protection0)
 			subgraphClusterNoLabel(sb, "p0");
-		}
+
 		sb.append("subgraph " + getClusterId() + " {");
 		sb.append("style=solid;");
 		sb.append("color=\"" + DotStringFactory.sharp000000(color) + "\";");
@@ -804,25 +792,25 @@ public class Cluster implements Moveable {
 
 		if (entityPositionsExceptNormal.size() > 0) {
 			printClusterEntryExit(sb, stringBounder);
-			if (hasPort()) {
+			if (hasPort())
 				subgraphClusterNoLabel(sb, ID_EE);
-			} else {
+			else
 				subgraphClusterWithLabel(sb, ID_EE, label);
-			}
+
 		} else {
 			sb.append("label=" + label + ";");
 			SvekUtils.println(sb);
 		}
 
-		if (thereALinkFromOrToGroup2) {
+		if (thereALinkFromOrToGroup2)
 			sb.append(getSpecialPointId(group) + " [shape=point,width=.01,label=\"\"];");
-		}
-		if (thereALinkFromOrToGroup1) {
+
+		if (thereALinkFromOrToGroup1)
 			subgraphClusterNoLabel(sb, "i");
-		}
-		if (protection1) {
+
+		if (protection1)
 			subgraphClusterNoLabel(sb, "p1");
-		}
+
 		if (skinParam.useSwimlanes(type)) {
 			sb.append("{rank = source; ");
 			sb.append(getSourceInPoint(type));
@@ -841,7 +829,7 @@ public class Cluster implements Moveable {
 		printCluster1(sb, lines, stringBounder);
 
 		final SvekNode added = printCluster2(sb, lines, stringBounder, dotMode, graphvizVersion, type);
-		if (entityPositionsExceptNormal.size() > 0) {
+		if (entityPositionsExceptNormal.size() > 0)
 			if (hasPort()) {
 				sb.append(empty() + " [shape=rect,width=.01,height=.01,label=");
 				sb.append(label);
@@ -849,32 +837,30 @@ public class Cluster implements Moveable {
 			} else if (added == null) {
 				sb.append(empty() + " [shape=point,width=.01,label=\"\"];");
 			}
-			SvekUtils.println(sb);
-		}
+		SvekUtils.println(sb);
 
 		sb.append("}");
-		if (protection1) {
+		if (protection1)
 			sb.append("}");
-		}
+
 		if (thereALinkFromOrToGroup1) {
 			sb.append("}");
 			sb.append("}");
 		}
-		if (entityPositionsExceptNormal.size() > 0) {
+		if (entityPositionsExceptNormal.size() > 0)
 			sb.append("}");
-		}
-		if (protection0) {
+
+		if (protection0)
 			sb.append("}");
-		}
+
 		SvekUtils.println(sb);
 	}
 
 	private boolean hasPort() {
-		for (EntityPosition pos : entityPositionsExceptNormal()) {
-			if (pos.isPort()) {
+		for (EntityPosition pos : entityPositionsExceptNormal())
+			if (pos.isPort())
 				return true;
-			}
-		}
+
 		return false;
 	}
 
@@ -908,57 +894,58 @@ public class Cluster implements Moveable {
 	}
 
 	private final HColor getBackColor(UmlDiagramType umlDiagramType, Style style) {
-		if (EntityUtils.groupRoot(group)) {
+		if (EntityUtils.groupRoot(group))
 			return null;
-		}
+
 		final HColor result = group.getColors().getColor(ColorType.BACK);
-		if (result != null) {
+		if (result != null)
 			return result;
-		}
+
 		final Stereotype stereo = group.getStereotype();
 
-		if (UseStyle.useBetaStyle()) {
+		if (UseStyle.useBetaStyle())
 			return style.value(PName.BackGroundColor).asColor(skinParam.getThemeStyle(), skinParam.getIHtmlColorSet());
-		}
 
 		final USymbol sym = group.getUSymbol() == null ? USymbol.PACKAGE : group.getUSymbol();
 		final ColorParam backparam = umlDiagramType == UmlDiagramType.ACTIVITY ? ColorParam.partitionBackground
 				: sym.getColorParamBack();
 		final HColor c1 = skinParam.getHtmlColor(backparam, stereo, false);
-		if (c1 != null) {
+		if (c1 != null)
 			return c1;
-		}
-		if (parentCluster == null) {
+
+		if (parentCluster == null)
 			return null;
-		}
+
 		return parentCluster.getBackColor(umlDiagramType, style);
 	}
 
 	public boolean isClusterOf(IEntity ent) {
-		if (ent.isGroup() == false) {
+		if (ent.isGroup() == false)
 			return false;
-		}
+
 		return group == ent;
 	}
 
-	public static HColor getBackColor(HColor backColor, ISkinParam skinParam, Stereotype stereotype, SName styleName) {
+	public static HColor getBackColor(HColor backColor, ISkinParam skinParam, Stereotype stereotype, SName styleName,
+			USymbol symbol) {
 		if (UseStyle.useBetaStyle()) {
-			final Style style = getDefaultStyleDefinition(styleName).getMergedStyle(skinParam.getCurrentStyleBuilder());
-			if (backColor == null) {
+			final Style style = getDefaultStyleDefinition(styleName, symbol)
+					.getMergedStyle(skinParam.getCurrentStyleBuilder());
+			if (backColor == null)
 				backColor = style.value(PName.BackGroundColor).asColor(skinParam.getThemeStyle(),
 						skinParam.getIHtmlColorSet());
-			}
-			if (backColor == null || backColor.equals(HColorUtils.transparent())) {
+
+			if (backColor == null || backColor.equals(HColorUtils.transparent()))
 				backColor = new HColorBackground(skinParam.getBackgroundColor());
-			}
+
 			return backColor;
 		}
-		if (backColor == null) {
+		if (backColor == null)
 			backColor = skinParam.getHtmlColor(ColorParam.packageBackground, stereotype, false);
-		}
-		if (backColor == null) {
+
+		if (backColor == null)
 			backColor = skinParam.getHtmlColor(ColorParam.background, stereotype, false);
-		}
+
 		if (backColor == null
 				|| backColor.equals(HColorUtils.transparent()) /* || stateBack instanceof HtmlColorTransparent */) {
 			final HColor tmp = skinParam.getBackgroundColor();
@@ -969,14 +956,13 @@ public class Cluster implements Moveable {
 
 	public double checkFolderPosition(Point2D pt, StringBounder stringBounder) {
 		if (getClusterPosition().isPointJustUpper(pt)) {
-			if (ztitle == null) {
+			if (ztitle == null)
 				return 0;
-			}
+
 			final Dimension2D dimTitle = ztitle.calculateDimension(stringBounder);
 
-			if (pt.getX() < getClusterPosition().getMinX() + dimTitle.getWidth()) {
+			if (pt.getX() < getClusterPosition().getMinX() + dimTitle.getWidth())
 				return 0;
-			}
 
 			return getClusterPosition().getMinY() - pt.getY() + dimTitle.getHeight();
 		}
