@@ -80,11 +80,11 @@ public final class CucaDiagramFileMakerSvek2InternalImage extends AbstractTextBl
 
 		Dimension2D add(Dimension2D orig, Dimension2D other) {
 			if (this == VERTICAL) {
-				return new Dimension2DDouble(orig.getWidth() + other.getWidth(), Math.max(orig.getHeight(),
-						other.getHeight()));
+				return new Dimension2DDouble(orig.getWidth() + other.getWidth(),
+						Math.max(orig.getHeight(), other.getHeight()));
 			}
-			return new Dimension2DDouble(Math.max(orig.getWidth(), other.getWidth()), orig.getHeight()
-					+ other.getHeight());
+			return new Dimension2DDouble(Math.max(orig.getWidth(), other.getWidth()),
+					orig.getHeight() + other.getHeight());
 		}
 
 		void drawSeparator(UGraphic ug, Dimension2D dimTotal) {
@@ -141,7 +141,7 @@ public final class CucaDiagramFileMakerSvek2InternalImage extends AbstractTextBl
 	public HColor getBackcolor() {
 		return skinParam.getBackgroundColor();
 	}
-	
+
 	public double getOverscanX(StringBounder stringBounder) {
 		return 0;
 	}
@@ -157,4 +157,5 @@ public final class CucaDiagramFileMakerSvek2InternalImage extends AbstractTextBl
 	public ShapeType getShapeType() {
 		return ShapeType.RECTANGLE;
 	}
+
 }
