@@ -47,7 +47,7 @@ import net.sourceforge.plantuml.ugraphic.UGraphic;
 import net.sourceforge.plantuml.ugraphic.UTranslate;
 import net.sourceforge.plantuml.ugraphic.color.HColor;
 
-public class EntityImageProtected extends AbstractTextBlock implements IEntityImage, Untranslated {
+public class EntityImageProtected extends AbstractTextBlock implements IEntityImage, Untranslated, WithPorts {
 
 	private final IEntityImage orig;
 	private final double border;
@@ -55,7 +55,9 @@ public class EntityImageProtected extends AbstractTextBlock implements IEntityIm
 	private final Neighborhood neighborhood;
 
 	public Rectangle2D getInnerPosition(String member, StringBounder stringBounder, InnerStrategy strategy) {
-		throw new UnsupportedOperationException();
+		final Rectangle2D result = orig.getInnerPosition(member, stringBounder, strategy);
+		return new Rectangle2D.Double(result.getMinX() + border, result.getMinY() + border, result.getWidth(),
+				result.getHeight());
 	}
 
 	public EntityImageProtected(IEntityImage orig, double border, Neighborhood neighborhood, Bibliotekon bibliotekon) {
@@ -98,4 +100,9 @@ public class EntityImageProtected extends AbstractTextBlock implements IEntityIm
 		return orig.getOverscanX(stringBounder);
 	}
 
+	@Override
+	public Ports getPorts(StringBounder stringBounder) {
+		return ((WithPorts) orig).getPorts(stringBounder);
+	}
+
 }
\ No newline at end of file
