@@ -2,7 +2,7 @@
  * PlantUML : a free UML diagram generator
  * ========================================================================
  *
- * (C) Copyright 2009-2017, Arnaud Roques
+ * (C) Copyright 2009-2020, Arnaud Roques
  *
  * Project Info:  http://plantuml.com
  * 
@@ -37,26 +37,24 @@ package net.sourceforge.plantuml.svek.extremity;
 
 import java.awt.geom.Point2D;
 
-import net.sourceforge.plantuml.graphic.HtmlColor;
-import net.sourceforge.plantuml.ugraphic.UChangeBackColor;
 import net.sourceforge.plantuml.ugraphic.UGraphic;
 import net.sourceforge.plantuml.ugraphic.UPolygon;
+import net.sourceforge.plantuml.ugraphic.color.HColorNone;
+import net.sourceforge.plantuml.ugraphic.color.HColorUtils;
 
 class ExtremityDiamond extends Extremity {
 
 	private UPolygon polygon = new UPolygon();
 	private final boolean fill;
 	private final Point2D contact;
-	private final HtmlColor backgroundColor;
 
 	@Override
 	public Point2D somePoint() {
 		return contact;
 	}
 
-	public ExtremityDiamond(Point2D p1, double angle, boolean fill, HtmlColor backgroundColor) {
+	public ExtremityDiamond(Point2D p1, double angle, boolean fill) {
 		this.fill = fill;
-		this.backgroundColor = backgroundColor;
 		this.contact = new Point2D.Double(p1.getX(), p1.getY());
 		angle = manageround(angle);
 		polygon.addPoint(0, 0);
@@ -71,12 +69,22 @@ class ExtremityDiamond extends Extremity {
 	}
 
 	public void drawU(UGraphic ug) {
-		if (fill) {
-			ug = ug.apply(new UChangeBackColor(ug.getParam().getColor()));
-		} else {
-			ug = ug.apply(new UChangeBackColor(backgroundColor));
-		}
+		if (fill)
+			ug = ug.apply(HColorUtils.changeBack(ug));
+		else
+			ug = ug.apply(new HColorNone().bg());
+
 		ug.draw(polygon);
 	}
 
+	@Override
+	public Point2D isTooSmallSoGiveThePointCloserToThisOne(Point2D pt) {
+		Point2D result = null;
+		for (Point2D p : polygon.getPoints())
+			if (result == null || p.distance(pt) < result.distance(pt))
+				result = p;
+
+		return result;
+	}
+
 }
