@@ -2,7 +2,7 @@
  * PlantUML : a free UML diagram generator
  * ========================================================================
  *
- * (C) Copyright 2009-2017, Arnaud Roques
+ * (C) Copyright 2009-2020, Arnaud Roques
  *
  * Project Info:  http://plantuml.com
  * 
@@ -34,26 +34,62 @@
  */
 package net.sourceforge.plantuml.timingdiagram;
 
+import net.sourceforge.plantuml.ISkinParam;
 import net.sourceforge.plantuml.cucadiagram.Display;
 import net.sourceforge.plantuml.cucadiagram.LinkDecor;
 import net.sourceforge.plantuml.cucadiagram.LinkType;
 import net.sourceforge.plantuml.cucadiagram.WithLinkType;
-import net.sourceforge.plantuml.graphic.HtmlColorUtils;
+import net.sourceforge.plantuml.style.PName;
+import net.sourceforge.plantuml.style.SName;
+import net.sourceforge.plantuml.style.Style;
+import net.sourceforge.plantuml.style.StyleBuilder;
+import net.sourceforge.plantuml.style.StyleSignature;
+import net.sourceforge.plantuml.ugraphic.UStroke;
+import net.sourceforge.plantuml.ugraphic.color.HColor;
+import net.sourceforge.plantuml.ugraphic.color.HColorUtils;
 
 public class TimeMessage extends WithLinkType {
 
 	private final TickInPlayer tickInPlayer1;
 	private final TickInPlayer tickInPlayer2;
 	private final Display label;
+	private final ISkinParam skinParam;
+	private final StyleBuilder styleBuilder;
 
-	public TimeMessage(TickInPlayer tickInPlayer1, TickInPlayer tickInPlayer2, String label) {
+	public TimeMessage(TickInPlayer tickInPlayer1, TickInPlayer tickInPlayer2, String label, ISkinParam skinParam) {
+		this.skinParam = skinParam;
+		this.styleBuilder = skinParam.getCurrentStyleBuilder();
 		this.tickInPlayer1 = tickInPlayer1;
 		this.tickInPlayer2 = tickInPlayer2;
 		this.label = Display.getWithNewlines(label);
-		this.setSpecificColor(HtmlColorUtils.BLUE);
+		this.setSpecificColor(getColor());
 		this.type = new LinkType(LinkDecor.NONE, LinkDecor.NONE);
 	}
 
+	@Override
+	public UStroke getUStroke() {
+		if (styleBuilder == null) {
+			return new UStroke(1.5);
+		}
+		return getStyle().getStroke();
+	}
+
+	private HColor getColor() {
+//		return HColorUtils.BLUE;
+		if (styleBuilder == null) {
+			return HColorUtils.MY_RED;
+		}
+		return getStyle().value(PName.LineColor).asColor(skinParam.getThemeStyle(), skinParam.getIHtmlColorSet());
+	}
+
+	private Style getStyle() {
+		return getStyleSignature().getMergedStyle(styleBuilder);
+	}
+
+	private StyleSignature getStyleSignature() {
+		return StyleSignature.of(SName.root, SName.element, SName.timingDiagram, SName.arrow);
+	}
+
 	public final Player getPlayer1() {
 		return tickInPlayer1.getPlayer();
 	}
