@@ -43,6 +43,7 @@ public class HColorSimple extends HColorAbstract implements HColor {
 
 	private final Color color;
 	private final boolean monochrome;
+	private HColor dark;
 
 	@Override
 	public int hashCode() {
@@ -112,6 +113,13 @@ public class HColorSimple extends HColorAbstract implements HColor {
 	public HColorSimple(Color c, boolean monochrome) {
 		this.color = c;
 		this.monochrome = monochrome;
+		this.dark = this;
+	}
+
+	private HColorSimple(Color c, boolean monochrome, HColor dark) {
+		this.color = c;
+		this.monochrome = monochrome;
+		this.dark = dark;
 	}
 
 	public Color getColor999() {
@@ -150,6 +158,14 @@ public class HColorSimple extends HColorAbstract implements HColor {
 		return monochrome;
 	}
 
+	public boolean isGray() {
+		if (monochrome)
+			return true;
+		if (color.getRed() == color.getGreen() && color.getGreen() == color.getBlue())
+			return true;
+		return false;
+	}
+
 	public static HColorSimple unlinear(HColorSimple color1, HColorSimple color2, int completionInt) {
 		final HSLColor col1 = new HSLColor(color1.color);
 		final HSLColor col2 = new HSLColor(color2.color);
@@ -180,4 +196,13 @@ public class HColorSimple extends HColorAbstract implements HColor {
 		return (x + (y - x) * factor);
 	}
 
+	public HColor withDark(HColor dark) {
+		return new HColorSimple(color, monochrome, dark);
+	}
+
+	@Override
+	public HColor darkSchemeTheme() {
+		return dark;
+	}
+
 }
