@@ -56,14 +56,13 @@ import net.sourceforge.plantuml.text.StyledString;
 import net.sourceforge.plantuml.ugraphic.UDriver;
 import net.sourceforge.plantuml.ugraphic.UFont;
 import net.sourceforge.plantuml.ugraphic.UParam;
-import net.sourceforge.plantuml.ugraphic.UShape;
 import net.sourceforge.plantuml.ugraphic.UText;
 import net.sourceforge.plantuml.ugraphic.color.ColorMapper;
 import net.sourceforge.plantuml.ugraphic.color.HColor;
 import net.sourceforge.plantuml.ugraphic.color.HColorGradient;
 import net.sourceforge.plantuml.ugraphic.color.HColorUtils;
 
-public class DriverTextG2d implements UDriver<Graphics2D> {
+public class DriverTextG2d implements UDriver<UText, Graphics2D> {
 
 	private final EnsureVisible visible;
 	private final StringBounder stringBounder;
@@ -73,8 +72,7 @@ public class DriverTextG2d implements UDriver<Graphics2D> {
 		this.stringBounder = stringBounder;
 	}
 
-	public void draw(UShape ushape, double x, double y, ColorMapper mapper, UParam param, Graphics2D g2d) {
-		final UText shape = (UText) ushape;
+	public void draw(UText shape, double x, double y, ColorMapper mapper, UParam param, Graphics2D g2d) {
 		final FontConfiguration fontConfiguration = shape.getFontConfiguration();
 
 		if (HColorUtils.isTransparent(fontConfiguration.getColor())) {
