@@ -2,7 +2,7 @@
  * PlantUML : a free UML diagram generator
  * ========================================================================
  *
- * (C) Copyright 2009-2017, Arnaud Roques
+ * (C) Copyright 2009-2020, Arnaud Roques
  *
  * Project Info:  http://plantuml.com
  * 
@@ -41,45 +41,52 @@ import java.util.regex.Pattern;
 import net.sourceforge.plantuml.AbstractPSystem;
 import net.sourceforge.plantuml.Log;
 import net.sourceforge.plantuml.command.PSystemSingleLineFactory;
+import net.sourceforge.plantuml.core.UmlSource;
+import net.sourceforge.plantuml.security.SecurityProfile;
+import net.sourceforge.plantuml.security.SecurityUtils;
 
 public class PSystemVersionFactory extends PSystemSingleLineFactory {
 
 	@Override
-	protected AbstractPSystem executeLine(String line) {
+	protected AbstractPSystem executeLine(UmlSource source, String line) {
 		try {
 			if (line.matches("(?i)^(authors?|about)\\s*$")) {
-				return PSystemVersion.createShowAuthors();
+				return PSystemVersion.createShowAuthors2(source);
 			}
 			if (line.matches("(?i)^version\\s*$")) {
-				return PSystemVersion.createShowVersion();
+				return PSystemVersion.createShowVersion2(source);
 			}
 			if (line.matches("(?i)^stdlib\\s*$")) {
-				return PSystemVersion.createStdLib();
+				return PSystemVersion.createStdLib(source);
 			}
+//			if (SecurityUtils.getSecurityProfile() == SecurityProfile.UNSECURE && line.matches("(?i)^path\\s*$")) {
+//				return PSystemVersion.createPath(source);
+//			}
 			if (line.matches("(?i)^testdot\\s*$")) {
-				return PSystemVersion.createTestDot();
+				return PSystemVersion.createTestDot(source);
 			}
-			if (line.matches("(?i)^checkversion\\s*$")) {
-				return PSystemVersion.createCheckVersions(null, null);
+//			if (SecurityUtils.getSecurityProfile() == SecurityProfile.UNSECURE
+//					&& line.matches("(?i)^dumpstacktrace\\s*$")) {
+//				return PSystemVersion.createDumpStackTrace();
+//			}
+			if (line.matches("(?i)^keydistributor\\s*$")) {
+				return PSystemVersion.createKeyDistributor(source);
 			}
-			if (line.matches("(?i)^keygen(\\s+[0-9a-z]+)?\\s*$")) {
+			if (line.matches("(?i)^keygen\\s*$")) {
 				line = line.trim();
-				final String key = line.substring("keygen".length()).trim();
-				return new PSystemKeygen(key);
+				return new PSystemKeygen(source, "");
 			}
-			final Pattern p1 = Pattern.compile("(?i)^checkversion\\(proxy=([\\w.]+),port=(\\d+)\\)$");
-			final Matcher m1 = p1.matcher(line);
-			if (m1.matches()) {
-				final String host = m1.group(1);
-				final String port = m1.group(2);
-				return PSystemVersion.createCheckVersions(host, port);
+			if (line.matches("(?i)^keyimport(\\s+[0-9a-z]+)?\\s*$")) {
+				line = line.trim();
+				final String key = line.substring("keyimport".length()).trim();
+				return new PSystemKeygen(source, key);
 			}
-			final Pattern p2 = Pattern.compile("(?i)^checkversion\\(proxy=([\\w.]+)\\)$");
-			final Matcher m2 = p2.matcher(line);
-			if (m2.matches()) {
-				final String host = m2.group(1);
-				final String port = "80";
-				return PSystemVersion.createCheckVersions(host, port);
+			if (line.matches("(?i)^keycheck\\s+([0-9a-z]+)\\s+([0-9a-z]+)\\s*$")) {
+				final Pattern p = Pattern.compile("(?i)^keycheck\\s+([0-9a-z]+)\\s+([0-9a-z]+)\\s*$");
+				final Matcher m = p.matcher(line);
+				if (m.find()) {
+					return new PSystemKeycheck(source, m.group(1), m.group(2));
+				}
 			}
 		} catch (IOException e) {
 			Log.error("Error " + e);
