@@ -1,5 +1,14 @@
 package net.sourceforge.plantuml;
 
+import static org.assertj.core.api.Assertions.assertThat;
+
+import java.awt.Color;
+
+import org.junit.jupiter.api.Test;
+import org.junit.jupiter.params.ParameterizedTest;
+import org.junit.jupiter.params.provider.CsvSource;
+import org.junit.jupiter.params.provider.EnumSource;
+
 import net.sourceforge.plantuml.cucadiagram.Rankdir;
 import net.sourceforge.plantuml.cucadiagram.Stereotype;
 import net.sourceforge.plantuml.cucadiagram.dot.DotSplines;
@@ -13,15 +22,6 @@ import net.sourceforge.plantuml.svg.LengthAdjust;
 import net.sourceforge.plantuml.ugraphic.color.ColorMapperIdentity;
 import net.sourceforge.plantuml.ugraphic.color.HColorUtils;
 
-import org.junit.jupiter.api.Test;
-import org.junit.jupiter.params.ParameterizedTest;
-import org.junit.jupiter.params.provider.CsvSource;
-import org.junit.jupiter.params.provider.EnumSource;
-
-import java.awt.Color;
-
-import static org.assertj.core.api.Assertions.assertThat;
-
 class SkinParamTest {
 
 	//
@@ -43,8 +43,7 @@ class SkinParamTest {
 
 		assertThat(skinParam.getAllSpriteNames()).isEmpty();
 
-		assertThat(skinParam.getBackgroundColor(false)).isEqualTo(HColorUtils.WHITE);
-		assertThat(skinParam.getBackgroundColor(true)).isEqualTo(HColorUtils.WHITE);
+		assertThat(skinParam.getBackgroundColor()).isEqualTo(HColorUtils.WHITE);
 
 		assertThat(skinParam.getCircledCharacter(fooStereotype)).isEqualTo('\0');
 
